Notebook[{
Cell["Applications of Summa.m ", "Title"],

Cell["A package for Symbolic and Infinite Sums Manipulation", "Subtitle"],

Cell["\<\
Package \t\tSumma.m \tVersion\t2.4e
Author\t\tPeltio (peltio@despammed.com)
Development \ton 2.2.1, refined on 3.0 and 4.x
Date\t\t\tMarch 2005\
\>", "Copyright"],

Cell["\<\
The main reason that prompted me to write the tiny package Summa \
was to allow my lazy self to check, without significant effort, the \
intermediate steps in the application of the power method to ordinary \
differential equations. Reindexing, collecting and simplifying sums may be \
quite straigthforward but it is nonetheless tedious when performed by hand. \
Incidentally, the manipulations required for that particular task extend to \
other fields, different from ODE solving and a few examples are given here. \
Despite the fact that the package is rather crude (it allows only for simple \
manipulations, without exerting any sort of control on user input - so beware \
of what you ask it to do!) there are several possible applications. The \
application of Summa.m to the solution of ordinary differential equations \
with the power method and with Frobenius' method is described in a separate \
notebook \"Power Method with Summa.m\".\
\>", "Text"],

Cell[TextData[{
  "A ",
  StyleBox["side effect",
    FontSlant->"Italic"],
  " of this package is that it is possible to use it to typeset formulae \
containing sums, preventing  any automatic and premature simplification by ",
  StyleBox["Mathematica;",
    FontSlant->"Italic"],
  " version 2 of Summa.m also allows the user to switch this behavior on and \
off at will, either globally or locally (i.e. limited to a single espression \
or part of an expresion). With version 2.3 it is also possibile to switch on \
and off the evaluation of When the expressions derived from subsequent \
manipulations of sums are needed, they can be obtained step by step as if 'by \
hand', thus avoiding direct typesetting of each intermediate formulae. But \
this is not merely a typesetting package: it can profitably be used to do \
some 'serious' symbolic manipulations on Sums as this notebook should now \
make clear."
}], "Text"],

Cell["\<\
In what follows, the adjectives 'symbolic', 'infinite' and \
'numeric' are used to denote sums with one or both symbolic, infinite or \
numerical (integer, to be exact) endpoints.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Initialization", "Subsection"],

Cell[TextData[{
  "This loads the package (remember to place it into the path of ",
  StyleBox["Mathematica)",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell["<<Summa.m", "Input",
  InitializationCell->True],

Cell["\<\
The symbols exported are given by ?Summa`*, but after the renaming \
occured in version 2.3 a more sensible list can be found with\
\>", "Text"],

Cell[CellGroupData[{

Cell["?Summa`Sum*", "Input"],

Cell["\<\
SumApply            Summa
SumApplyAt          SumMap
SumCoefficient      SumMapAt
SumD                SummaToSum
SumDEach            SumPosition
SumEvaluationStatus SumReIndex
SumExpand           SumSimplify
SumExpandAll        SumSimplifyEach
SumExponentAlign    SumSimplifySum
SumFullSimplify     SumSplit
SumFullSimplifyEach SumToSumma
SumIndexAlign       SumToTerm
SumIntegrate\
\>", "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->GrayLevel[0.930022],
  ButtonBoxOptions->{Active->True}]
}, Open  ]],

Cell["\<\
The basic object defined in the package is Summa, a container that \
substitutes Sum and prevents evaluation. If you choose to disable the \
built-in Sum Evaluation to perform your symbolic manipulations, you won't \
even need to know a thing about it since it will be used transparently to the \
user (who will operate on Sum objects and will see output formatted as \
Sums.\
\>", "Text"],

Cell[CellGroupData[{

Cell["?Summa", "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`"Abstract type to denote a symbolic or infinite sum.\n  \
s=Summa[element,{k,ki,kf}]\n  Summa objects with one or both symbolic or \
infinite endpoint  are left unevaluated (and displayed as formatted Sums) to \
allow  further manipulation. Summa objects with integer endpoints   are \
evaluated as built-in Sums. Summa object with symbolic or   infinite \
endpoints whose closed form is known to Mathematica   are kept internally \
unevaluated, but can be displayed either  as unevaluated Sums or as the \
result of the evaluation (see  help for SetSumFormat)."\)], "Print"]
}, Open  ]],

Cell["\<\
The other two main functions are devoted to enabling and disabling \
(either locally and globally) the original built-in evaluation associated \
with Sum. They are described in the next paragraph\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Basic manipulation of finite symbolic sums", "Section"],

Cell["\<\
The following will show how to use the package Summa to find a \
closed form solution for the sum of an arithmetic progression. In this we \
will adopt the method devised by Gauss.\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\tS = \[Sum]\+\(k = 0\)\%n\((a + b\ k)\)\)\)], "Text",\

  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["\<\
We start by writing our Sum with the standard order of summation: \
from 0 to n\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sa = Sum[a + b\ k, {k, 0, n}]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[\(\[Sum]\+\(k = 0\)\%n\((a + b\ k)\)\),
        HoldForm], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
We can look at the sum in a different way, thanks to the \
commutative property. In fact we can begin to to add its terms from the end. \
We can thus change the index from k to n-k \
\>", "Text"],

Cell[TextData[{
  "and use the function SumReverse in order to state the equivalence between \
",
  Cell[BoxData[
      \(TraditionalForm
      \`\(c\_n + c\_\(n - 1\) +  ... \) + c\_1 + c\_0 = 
        \(c\_0 + c\_1 +  ... \) + c\_\(n - 1\) + c\_n\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SumReIndex[Sa, k \[Rule] n - k]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[\(\[Sum]\+\(k = n\)\%0\((a + b\ \((n - k)\))\)\),
        HoldForm], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
and write a function SumReverse to exchange the sum's limits.We do \
it by usign Summa in the body of the procedure in order to be able to use it \
even if later on we should choose to enable ordinary Sum evaluation. We could \
have used Sum, if we wanted to, because every occurence of Sum, when Sum \
evaluation is disabled, is converted into a Summa object.\
\>", "Text"],

Cell[BoxData[
    \(SumReverse[Summa[el_, {k_, ko_, k1_}]] := Summa[el, {k, k1, ko}]\)], 
  "Input"],

Cell[TextData[{
  "Now we use our new function to state the equivalence between ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(c\_n + c\_\(n - 1\) +  ... \) + c\_1 + c\_0 = 
        \(c\_0 + c\_1 +  ... \) + c\_\(n - 1\) + c\_n\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sb = SumReverse[%%]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[\(\[Sum]\+\(k = 0\)\%n\((a + b\ \((n - k)\))\)\),
        HoldForm], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Since sums Sa and Sb are the same as sum S, if we add them together \
we get twice the sum we are trying to express in closed form. We can then see \
that even if we don't know how to express S in closed form, we can easily \
spot the value of the sum Sa + Sb:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SumSimplify[2  S == Sa + Sb]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(2\ S\), "==", 
        FormBox[
          TagBox[\(\[Sum]\+\(k = 0\)\%n\((2\ a + b\ n)\)\),
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "We are almost done. We could let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " act on the sum at the rhs to find its closed form, but it would not be \
fair; after all, if we wanted mathematica to do all the work for us we cold \
have evaluated the sum right at the first step. Since we want to push our \
manipulation as far as possible, we take the index-free term (2a+b n)  out of \
the sum, by means of BringOut"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BringOut[%, 2  a + b\ n]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(2\ S\), "==", 
        RowBox[{\((2\ a + b\ n)\), " ", 
          FormBox[
            TagBox[\(\[Sum]\+\(k = 0\)\%n 1\),
              HoldForm],
            "TraditionalForm"]}]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now all we have to do is to count from 0 to n. That would be... let's \
see... (n+1). At this point we could even let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " do this step for us, thus saving us a manual replacement of the two \
elementary sums"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(EnableSumEvaluation[%]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`2\ S == \((n + 1)\)\ \((2\ a + b\ n)\)\)], "Output"]
}, Open  ]],

Cell["\<\
We can finally solve for S and find the closed form solution for \
our arithmetic progression problem:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[%, S] // Simplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{{S \[Rule] 1\/2\ \((n + 1)\)\ \((2\ a + b\ n)\)}}\)], 
  "Output"]
}, Open  ]],

Cell[TextData[{
  "That's it. Of course ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " knew this answer all along. But we have been able to perform ",
  StyleBox["every single step ",
    FontSlant->"Italic"],
  "of the solution as if by hand, verifying our technique without having to \
carry on tedious substitutions with pencil and paper. Granted, the example is \
quite trivial but covering the boring steps of sum manipulation is indeed ",
  StyleBox["one",
    FontSlant->"Italic"],
  " of the aims of the Summa package."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Perturbation method for finite sums", "Section"],

Cell[TextData[{
  "The following examples are taken from \"",
  StyleBox["Concrete Mathematics",
    FontSlant->"Italic"],
  "\", by Graham, Knuth, Patashnik. In chapter 2 the authors show how to \
apply the perturbation method to get a closed form for the sum of the first n \
powers of x and of element in the form k ",
  Cell[BoxData[
      \(TraditionalForm\`x\^k\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "The ",
  StyleBox["perturbation method",
    FontWeight->"Bold"],
  " applied to the sum"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`S\_n = \[Sum]\+\(k = 0\)\%n a\_k\)], "Text"],

Cell[TextData[{
  "consists in writing the sum ",
  Cell[BoxData[
      \(TraditionalForm\`S\_\(n + 1\)\)]],
  "with (n+1) terms in two different ways: one that takes the last term out \
thus exposing the sum ",
  Cell[BoxData[
      \(TraditionalForm\`S\_n\)]],
  "of the first n terms, and another one that takes the first term out. We \
then rearrange the latter sum's index in order to have the same starting \
point as the sum ",
  Cell[BoxData[
      \(TraditionalForm\`S\_n\)]]
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\t
    S\_\(n + 1\) = 
      \(\(\[Sum]\+\(k = 0\)\%\(n + 1\)a\_k = 
            \(\[Sum]\+\(k = 0\)\%n a\_k + a\_\(n + 1\) = 
              S\_n + a\_\(n + 1\)\)\)\n\tS\_\(n + 1\) = 
        \(\[Sum]\+\(k = 0\)\%\(n + 1\)a\_k = 
          \(a\_0 + \[Sum]\+\(k = 1\)\%\(n + 1\)a\_k = 
            a\_0 + \[Sum]\+\(k = 0\)\%n a\_\(k + 1\)\)\)\)\)\)], "Text"],

Cell["And then we equate the two forms to obtain an equation ", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\t
    S\_n + a\_\(n + 1\) = a\_0 + \[Sum]\+\(k = 0\)\%n a\_\(k + 1\)\)\)], 
  "Text"],

Cell[TextData[{
  "that can be solved if we can rewrite the last sum as a function of initial \
sum ",
  Cell[BoxData[
      \(TraditionalForm\`S\_n\)]],
  "(when powers of x are involved, multiplying or dividing by the correct \
powers of x can work the trick, as we shall soon see)"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\tS\_n + a\_\(n + 1\) = f(S\_n) + a\_0\)\)], "Text"],

Cell[TextData[{
  "We thus have an equation in ",
  Cell[BoxData[
      \(TraditionalForm\`S\_n\)]],
  "whose solution is the closed form we were looking for."
}], "Text"],

Cell[CellGroupData[{

Cell["Geometric Progression", "Subsubsection"],

Cell[TextData[{
  "This example makes use of the function ",
  StyleBox["BringOut[sum,x]",
    FontWeight->"Bold"],
  " introduced in version 2.2 of the package. Here we show all the passages \
in one single pass. We start with ",
  Cell[BoxData[
      \(TraditionalForm\`S\_n\)]]
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{"\t", 
        RowBox[{\(S\_n\), "=", 
          TagBox[\(\[Sum]\+\(k = 0\)\%n x\^k\),
            HoldForm]}]}], TraditionalForm]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["\<\
and we generate all the steps needed to find a closed form for this \
sum. Please note that on certain older versions Solve could choke on the \
subscripted variable.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(eq = S\_n + x\^\(n + 1\) \[Equal] Sum[x\^k, {k, 0, n + 1}]\), 
    \(eq = SumSplit[eq, 1]\), 
    \(eq = SumIndexAlign[eq, {k, 0}]\), 
    \(eq = BringOut[eq, x]\), 
    \(eq = eq /. Sum[x^k, {k, 0, n}] \[Rule] S\_n\), 
    \(Solve[eq, S\_n]\)}], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(x\^\(n + 1\) + S\_n\), "==", 
        FormBox[
          TagBox[\(\[Sum]\+\(k = 0\)\%\(n + 1\)x\^k\),
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      RowBox[{\(x\^\(n + 1\) + S\_n\), "==", 
        RowBox[{
          FormBox[
            TagBox[\(\[Sum]\+\(k = 1\)\%\(n + 1\)x\^k\),
              HoldForm],
            "TraditionalForm"], "+", "1"}]}], TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      RowBox[{\(x\^\(n + 1\) + S\_n\), "==", 
        RowBox[{
          FormBox[
            TagBox[\(\[Sum]\+\(k = 0\)\%n x\^\(k + 1\)\),
              HoldForm],
            "TraditionalForm"], "+", "1"}]}], TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      RowBox[{\(x\^\(n + 1\) + S\_n\), "==", 
        RowBox[{
          RowBox[{"x", " ", 
            FormBox[
              TagBox[\(\[Sum]\+\(k = 0\)\%n x\^k\),
                HoldForm],
              "TraditionalForm"]}], "+", "1"}]}], TraditionalForm]], "Output"],

Cell[BoxData[
    \(TraditionalForm\`x\^\(n + 1\) + S\_n == x\ S\_n + 1\)], "Output"],

Cell[BoxData[
    \(TraditionalForm\`{{S\_n \[Rule] \(1 - x\^\(n + 1\)\)\/\(1 - x\)}}\)], 
  "Output"]
}, Open  ]],

Cell["\<\
Once we have this all done, we could intersperse the output with \
our comments. Instructions on the passages to be carried on has spared us a \
dull input session of bidimensional forms. The gain in time is better \
appreciated when treating sums whose terms depend on different values of the \
index.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Two methods to find a sum's closed form", "Subsubsection"],

Cell["\<\
Starting from our expression for the closed form of the above sum, \
we can derive a further relationship by differentiating both sides of the \
folowing equality:\
\>", "Text"],

Cell[BoxData[
    \(\(eq = \[Sum]\+\(k = 0\)\%n x\^k == \(1 - x\^\(n + 1\)\)\/\(1 - x\); 
    \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SumD[eq, x] // Simplify\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          TagBox[\(\[Sum]\+\(k = 0\)\%n k\ x\^\(k - 1\)\),
            HoldForm],
          "TraditionalForm"], "==", 
        \(\(\(-\((n + 1)\)\)\ x\^n + n\ x\^\(n + 1\) + 1\)\/\((x - 1)\)\^2
              \)}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
We can align the exponent of the sum in the lhs without changing \
the endpoints. Using BringIn to multiply the addendum by x and premultiplying \
the whole sum by 1/x we get:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BringIn[%, x]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          FormBox[
            TagBox[\(\[Sum]\+\(k = 0\)\%n k\ x\^k\),
              HoldForm],
            "TraditionalForm"], "x"], "==", 
        \(\(\(-\((n + 1)\)\)\ x\^n + n\ x\^\(n + 1\) + 1\)\/\((x - 1)\)\^2
              \)}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "by multiplying both sides by x we get the closed form for the sum of ",
  Cell[BoxData[
      \(TraditionalForm\`k*x\^k\)]],
  ". We use a pure function and ",
  StyleBox["Map",
    FontWeight->"Bold"],
  " to perform this task on both sides"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(x\ #&\)\ /@\ %\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          TagBox[\(\[Sum]\+\(k = 0\)\%n k\ x\^k\),
            HoldForm],
          "TraditionalForm"], "==", 
        \(\(x\ \((\(-\((n + 1)\)\)\ x\^n + n\ x\^\(n + 1\) + 1)\)\)\/\((x - 1)
                \)\^2\)}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\

We could have obtained the same expression by means of the perturbation \
method applied to the sum investigated. Following Graham, Knuth and Patashnik \
we start from\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{"\t", 
        RowBox[{\(S\_n\), "=", 
          TagBox[\(\[Sum]\+\(k = 0\)\%n k\ x\^k\),
            HoldForm]}]}], TraditionalForm]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[TextData[{
  "and we perturb the sum ",
  Cell[BoxData[
      \(TraditionalForm\`S\_\(n + 1\)\)]],
  "in the following way:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq = 
      S\_n + \((n + 1)\) x\^\(n + 1\) \[Equal] 
        Sum[k\ x\^k, {k, 0, n + 1}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\((n + 1)\)\ x\^\(n + 1\) + S\_n\), "==", 
        FormBox[
          TagBox[\(\[Sum]\+\(k = 0\)\%\(n + 1\)k\ x\^k\),
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
The first term of the sum at the rhs is 0*x^0=0. By expliciting \
this and by realigning the index at 0 we get\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq = SumSplit[eq, 1]; \neq = SumIndexAlign[eq, {k, 0}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\((n + 1)\)\ x\^\(n + 1\) + S\_n\), "==", 
        FormBox[
          TagBox[\(\[Sum]\+\(k = 0\)\%n\((k + 1)\)\ x\^\(k + 1\)\),
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now, to express the sum in the above equation in term of our initial ",
  Cell[BoxData[
      \(TraditionalForm\`S\_n\)]],
  ", we expand the sum with ",
  StyleBox["ExpandAllSum",
    FontWeight->"Bold"],
  " (that iterates ",
  StyleBox["ExpandSum",
    FontWeight->"Bold"],
  " until everything has been 'unknotted')"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq = SumExpandAll[eq]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(n\ x\^\(n + 1\) + x\^\(n + 1\) + S\_n\), "==", 
        RowBox[{
          FormBox[
            TagBox[\(\[Sum]\+\(k = 0\)\%n x\^\(k + 1\)\),
              HoldForm],
            "TraditionalForm"], "+", 
          FormBox[
            TagBox[\(\[Sum]\+\(k = 0\)\%n k\ x\^\(k + 1\)\),
              HoldForm],
            "TraditionalForm"]}]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
If we divide each addendum by x, premultiplying the sum by the same \
amount, we can get the exponent of the powers of x inside the sums aligned to \
just k.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq = BringOut[eq, x]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(n\ x\^\(n + 1\) + x\^\(n + 1\) + S\_n\), "==", 
        RowBox[{
          RowBox[{"x", " ", 
            FormBox[
              TagBox[\(\[Sum]\+\(k = 0\)\%n x\^k\),
                HoldForm],
              "TraditionalForm"]}], "+", 
          RowBox[{"x", " ", 
            FormBox[
              TagBox[\(\[Sum]\+\(k = 0\)\%n k\ x\^k\),
                HoldForm],
              "TraditionalForm"]}]}]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now all we have to do is to substitute for the known sums: the former \
totals to",
  Cell[BoxData[
      \(TraditionalForm\`\(1 - x\^\(n + 1\)\)\/\(1 - x\)\)]],
  ", while the latter is the sought unknown ",
  Cell[BoxData[
      \(TraditionalForm\`S\_n\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq = 
      eq /. {\[IndentingNewLine]Sum[\ x^k, {k, 0, n}] \[Rule] 
            \(1 - x\^\(n + 1\)\)\/\(1 - x\), 
          \[IndentingNewLine]Sum[k\ x^k, {k, 0, n}] \[Rule] S\_n}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`n\ x\^\(n + 1\) + x\^\(n + 1\) + S\_n == 
      \(x\ \((1 - x\^\(n + 1\))\)\)\/\(1 - x\) + x\ S\_n\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We're done. We only have to solve for ",
  Cell[BoxData[
      \(TraditionalForm\`S\_n\)]],
  "to get our answer:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[eq, S\_n] // Simplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{{S\_n \[Rule] 
          \(x\ \((\(-\((n + 1)\)\)\ x\^n + n\ x\^\(n + 1\) + 1)\)\)\/\((x - 1)
                \)\^2}}\)], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Least square fit", "Section"],

Cell["Let's find the expression of the coefficients of the line", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\ty\_fit = \[Beta]0 + x\ \[Beta]1\)\)], "Text",
  Evaluatable->False],

Cell[TextData[{
  "that fits a set of points ",
  Cell[BoxData[
      \(TraditionalForm\`{x\_k, y\_k}\)]],
  " (k=1 to n) following the least square method. In order to do this we have \
to minimize the sum of square errors"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\t
    SSE = \[Sum]\+\(k = 1\)\%n\((y\_k - y\_fit)\)\^2\)\)], "Text",
  Evaluatable->False],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`y\_fit\)]],
  " is given by the equation above. Direct substitution of ",
  Cell[BoxData[
      \(TraditionalForm\`y\_fit\)]],
  "in the formula for SSE yields:"
}], "Text"],

Cell[BoxData[
    \(Clear[x, y]; \n
    sse = Sum[\((y\_k - \((\[Beta]0 + \[Beta]1\ x\_k)\))\)^2, {k, 1, n}]; 
    \)], "Input"],

Cell["\<\
All we have to do is to compute the partial derivatives with \
respect to the coefficients and to find out for which values the derivatives \
go to zero. Our first attempt at writing the first equation is\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(SumD[sse, \[Beta]0] == 0 // SumExpand\) // BringOut\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"2", " ", "\[Beta]0", " ", 
            FormBox[
              TagBox[\(\[Sum]\+\(k = 1\)\%n 1\),
                HoldForm],
              "TraditionalForm"]}], "+", 
          RowBox[{"2", " ", "\[Beta]1", " ", 
            FormBox[
              TagBox[\(\[Sum]\+\(k = 1\)\%n x\_k\),
                HoldForm],
              "TraditionalForm"]}], "-", 
          RowBox[{"2", " ", 
            FormBox[
              TagBox[\(\[Sum]\+\(k = 1\)\%n y\_k\),
                HoldForm],
              "TraditionalForm"]}]}], "==", "0"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
It's nice but not quite what we want. Let's get rid of the common \
factor 2 and simplify the sum of 1's from 1 to n by allowing Mathematica to \
locally operate on it as a Sum object (we must keep in mind that even though \
Sums are displayed, the internal representation consists of Summa objects). \
We restate our code in this way:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq1 = 
      \((\(SumD[sse, \[Beta]0]/2 == 0 // SumExpand\) // BringOut)\) // 
        EnableSumEvaluation\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(n\ \[Beta]0\), "+", 
          RowBox[{"\[Beta]1", " ", 
            FormBox[
              TagBox[\(\[Sum]\+\(k = 1\)\%n x\_k\),
                HoldForm],
              "TraditionalForm"]}], "-", 
          FormBox[
            TagBox[\(\[Sum]\+\(k = 1\)\%n y\_k\),
              HoldForm],
            "TraditionalForm"]}], "==", "0"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["The second equation is more easily obtained:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq2 = \(SumD[sse, \[Beta]1]/2 == 0 // SumExpand\) // BringOut\)], 
  "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[Beta]0", " ", 
            FormBox[
              TagBox[\(\[Sum]\+\(k = 1\)\%n x\_k\),
                HoldForm],
              "TraditionalForm"]}], "+", 
          RowBox[{"\[Beta]1", " ", 
            FormBox[
              TagBox[\(\[Sum]\+\(k = 1\)\%n x\_k\%2\),
                HoldForm],
              "TraditionalForm"]}], "-", 
          FormBox[
            TagBox[\(\[Sum]\+\(k = 1\)\%n x\_k\ y\_k\),
              HoldForm],
            "TraditionalForm"]}], "==", "0"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[
"Solving for \[Beta]0 and \[Beta]1 yields the desired solution"], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(coeff = Solve[{eq1, eq2}, {\[Beta]0, \[Beta]1}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"\[Beta]0", "\[Rule]", 
              RowBox[{"-", 
                FractionBox[
                  RowBox[{
                    RowBox[{
                      RowBox[{"(", 
                        FormBox[
                          TagBox[\(\[Sum]\+\(k = 1\)\%n x\_k\),
                            HoldForm],
                          "TraditionalForm"], ")"}], " ", 
                      FormBox[
                        TagBox[\(\[Sum]\+\(k = 1\)\%n x\_k\ y\_k\),
                          HoldForm],
                        "TraditionalForm"]}], "-", 
                    RowBox[{
                      RowBox[{"(", 
                        FormBox[
                          TagBox[\(\[Sum]\+\(k = 1\)\%n x\_k\%2\),
                            HoldForm],
                          "TraditionalForm"], ")"}], " ", 
                      FormBox[
                        TagBox[\(\[Sum]\+\(k = 1\)\%n y\_k\),
                          HoldForm],
                        "TraditionalForm"]}]}], 
                  RowBox[{
                    RowBox[{"n", " ", 
                      FormBox[
                        TagBox[\(\[Sum]\+\(k = 1\)\%n x\_k\%2\),
                          HoldForm],
                        "TraditionalForm"]}], "-", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          TagBox[\(\[Sum]\+\(k = 1\)\%n x\_k\),
                            HoldForm],
                          "TraditionalForm"], ")"}], "2"]}]]}]}], ",", 
            RowBox[{"\[Beta]1", "\[Rule]", 
              RowBox[{"-", 
                FractionBox[
                  RowBox[{
                    RowBox[{
                      RowBox[{"(", 
                        FormBox[
                          TagBox[\(\[Sum]\+\(k = 1\)\%n x\_k\),
                            HoldForm],
                          "TraditionalForm"], ")"}], " ", 
                      FormBox[
                        TagBox[\(\[Sum]\+\(k = 1\)\%n y\_k\),
                          HoldForm],
                        "TraditionalForm"]}], "-", 
                    RowBox[{"n", " ", 
                      FormBox[
                        TagBox[\(\[Sum]\+\(k = 1\)\%n x\_k\ y\_k\),
                          HoldForm],
                        "TraditionalForm"]}]}], 
                  RowBox[{
                    RowBox[{"n", " ", 
                      FormBox[
                        TagBox[\(\[Sum]\+\(k = 1\)\%n x\_k\%2\),
                          HoldForm],
                        "TraditionalForm"]}], "-", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        FormBox[
                          TagBox[\(\[Sum]\+\(k = 1\)\%n x\_k\),
                            HoldForm],
                          "TraditionalForm"], ")"}], "2"]}]]}]}]}], "}"}], 
        "}"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[
"\n\nWe can try to further simplify the expressions we obtained. Let's work \
on \[Beta]1 first"], "Text"],

Cell[BoxData[
    \(b1 = \[Beta]1 /. coeff[\([1]\)]; \nnum = Numerator[b1]/n // Apart; \n
    den = Denominator[\ b1]/n // Apart; \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(b1 = num/den\)], "Input"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          FormBox[
            TagBox[\(\[Sum]\+\(k = 1\)\%n x\_k\ y\_k\),
              HoldForm],
            "TraditionalForm"], "-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                FormBox[
                  TagBox[\(\[Sum]\+\(k = 1\)\%n x\_k\),
                    HoldForm],
                  "TraditionalForm"], ")"}], " ", 
              FormBox[
                TagBox[\(\[Sum]\+\(k = 1\)\%n y\_k\),
                  HoldForm],
                "TraditionalForm"]}], "n"]}], 
        RowBox[{
          FormBox[
            TagBox[\(\[Sum]\+\(k = 1\)\%n x\_k\%2\),
              HoldForm],
            "TraditionalForm"], "-", 
          FractionBox[
            SuperscriptBox[
              RowBox[{"(", 
                FormBox[
                  TagBox[\(\[Sum]\+\(k = 1\)\%n x\_k\),
                    HoldForm],
                  "TraditionalForm"], ")"}], "2"], "n"]}]], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(meanRule = {\n\t
        Sum[x\_k, {k, 1, n}] -> n\ \ \[DoubleStruckCapitalE][x], \n\t
        Sum[y\_k, {k, 1, n}] -> n\ \[DoubleStruckCapitalE][y]}; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(b1 = b1 /. meanRule // Simplify\)], "Input"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          FormBox[
            TagBox[\(\[Sum]\+\(k = 1\)\%n x\_k\ y\_k\),
              HoldForm],
            "TraditionalForm"], "-", 
          \(n\ \(\[DoubleStruckCapitalE](x)\)\ 
            \(\[DoubleStruckCapitalE](y)\)\)}], 
        RowBox[{
          FormBox[
            TagBox[\(\[Sum]\+\(k = 1\)\%n x\_k\%2\),
              HoldForm],
            "TraditionalForm"], "-", 
          \(n\ \(\[DoubleStruckCapitalE](x)\)\^2\)}]], TraditionalForm]], 
  "Output"]
}, Open  ]],

Cell[TextData["We can do the same with \[Beta]0"], "Text"],

Cell[BoxData[
    \(b0 = \[Beta]0 /. coeff[\([1]\)]; \nnum = Numerator[b0]/n // Apart; \n
    den = Denominator[\ b0]/n // Apart; \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(b0 = num/den /. meanRule\)], "Input"],

Cell[BoxData[
    FormBox[
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              FormBox[
                TagBox[\(\[Sum]\+\(k = 1\)\%n x\_k\%2\),
                  HoldForm],
                "TraditionalForm"], ")"}], " ", 
            \(\[DoubleStruckCapitalE](y)\)}], "-", 
          RowBox[{
            RowBox[{"(", 
              FormBox[
                TagBox[\(\[Sum]\+\(k = 1\)\%n x\_k\ y\_k\),
                  HoldForm],
                "TraditionalForm"], ")"}], " ", 
            \(\[DoubleStruckCapitalE](x)\)}]}], 
        RowBox[{
          FormBox[
            TagBox[\(\[Sum]\+\(k = 1\)\%n x\_k\%2\),
              HoldForm],
            "TraditionalForm"], "-", 
          \(n\ \(\[DoubleStruckCapitalE](x)\)\^2\)}]], TraditionalForm]], 
  "Output"]
}, Open  ]],

Cell[TextData[
"But, once we know \[Beta]1, it is better to find \[Beta]0 in the following \
way"], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(b0 = 
      \(\[Beta]0 /. \(Solve[eq1, \[Beta]0]\)[\([1]\)]\) /. meanRule // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`\[DoubleStruckCapitalE](y) - 
      \[Beta]1\ \(\[DoubleStruckCapitalE](x)\)\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Solving Ordinary Differential Equations by series expansion", "Section"],

Cell["\<\
More on this is to be found in the separate notebook \"The Power \
Method with Summa\". 
Let's try to solve the following ODE with the power method, in a neighbor of \
x=0\
\>", "Text"],

Cell[BoxData[
    \(\(eq = \(\(y'\)'\)[x] - 2 \((x + 3)\) \(y'\)[x] - 3  y[x] == 0; \)\)], 
  "Input"],

Cell["\<\
Since the coefficients are polynomials, they are already in the \
form  of power series of x. We now substitute y[x] and its derivatives with \
power series of x=(x-0) :\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({ys = Sum[a[n] x^n, {n, 0, Infinity}], \n\ty1s = DSum[ys, x], \n\t
      y2s = DSum[y1s, x]}\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(n = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(x\^n\ \(a(n)\)\)}],
              HoldForm],
            "TraditionalForm"], ",", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(n = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(n\ x\^\(n - 1\)\ \(a(n)\)\)}],
              HoldForm],
            "TraditionalForm"], ",", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(n = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], 
                \(\((n - 1)\)\ n\ x\^\(n - 2\)\ \(a(n)\)\)}],
              HoldForm],
            "TraditionalForm"]}], "}"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["We get", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eqs = eq /. {y[x] -> ys, \(y'\)[x] -> y1s, \(\(y'\)'\)[x] -> y2s}\)], 
  "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(n = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], 
                \(\((n - 1)\)\ n\ x\^\(n - 2\)\ \(a(n)\)\)}],
              HoldForm],
            "TraditionalForm"], "-", 
          RowBox[{"2", " ", \((x + 3)\), " ", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", \(n = 0\), 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]], 
                  \(n\ x\^\(n - 1\)\ \(a(n)\)\)}],
                HoldForm],
              "TraditionalForm"]}], "-", 
          RowBox[{"3", " ", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", \(n = 0\), 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]], \(x\^n\ \(a(n)\)\)}],
                HoldForm],
              "TraditionalForm"]}]}], "==", "0"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(eqs = SumExpandAll[eqs]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(n = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], 
                \(\(-n\)\ x\^\(n - 2\)\ \(a(n)\)\)}],
              HoldForm],
            "TraditionalForm"], "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(n = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], 
                \(n\^2\ x\^\(n - 2\)\ \(a(n)\)\)}],
              HoldForm],
            "TraditionalForm"], "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(n = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], 
                \(\(-6\)\ n\ x\^\(n - 1\)\ \(a(n)\)\)}],
              HoldForm],
            "TraditionalForm"], "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(n = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(\(-3\)\ x\^n\ \(a(n)\)\)}],
              HoldForm],
            "TraditionalForm"], "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(n = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(\(-2\)\ n\ x\^n\ \(a(n)\)\)}],
              HoldForm],
            "TraditionalForm"]}], "==", "0"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Now we write all the sums in terms of powers of x^n, by realigning \
the exponents.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eqs = SumExponentAlign[eqs, x, n -> n]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(n = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(\(-3\)\ x\^n\ \(a(n)\)\)}],
              HoldForm],
            "TraditionalForm"], "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(n = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(\(-2\)\ n\ x\^n\ \(a(n)\)\)}],
              HoldForm],
            "TraditionalForm"], "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(n = \(-1\)\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], 
                \(\(-6\)\ \((n + 1)\)\ x\^n\ \(a(n + 1)\)\)}],
              HoldForm],
            "TraditionalForm"], "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(n = \(-2\)\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], 
                \(\(-\((n + 2)\)\)\ x\^n\ \(a(n + 2)\)\)}],
              HoldForm],
            "TraditionalForm"], "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(n = \(-2\)\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], 
                \(\((n + 2)\)\^2\ x\^n\ \(a(n + 2)\)\)}],
              HoldForm],
            "TraditionalForm"]}], "==", "0"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
then we explicit the first terms (they turn out to be zero) in \
order to have all the sum starting from the same point. BreakSum will do this\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SumSplit[eqs, 0]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(n = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(\(-3\)\ x\^n\ \(a(n)\)\)}],
              HoldForm],
            "TraditionalForm"], "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(n = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(\(-2\)\ n\ x\^n\ \(a(n)\)\)}],
              HoldForm],
            "TraditionalForm"], "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(n = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], 
                \(\(-6\)\ \((n + 1)\)\ x\^n\ \(a(n + 1)\)\)}],
              HoldForm],
            "TraditionalForm"], "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(n = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], 
                \(\(-\((n + 2)\)\)\ x\^n\ \(a(n + 2)\)\)}],
              HoldForm],
            "TraditionalForm"], "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(n = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], 
                \(\((n + 2)\)\^2\ x\^n\ \(a(n + 2)\)\)}],
              HoldForm],
            "TraditionalForm"]}], "==", "0"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["After simplification we get a single sum", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(res = SumSimplify[%]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(n = 0\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], 
              \(x\^n\ \((
                  \((n + 1)\)\ 
                      \((\((n + 2)\)\ \(a(n + 2)\) - 6\ \(a(n + 1)\))\) - 
                    \((2\ n + 3)\)\ \(a(n)\))\)\)}],
            HoldForm],
          "TraditionalForm"], "==", "0"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
whose coefficient need to be zero in order for the equality to hold \
for every x. The equation is\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eqRecur = SumCoefficient[res, x^n] == 0\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`\(a(n + 2)\)\ n\^2 - 2\ \(a(n)\)\ n - 6\ \(a(n + 1)\)\ n + 
        3\ \(a(n + 2)\)\ n - 3\ \(a(n)\) - 6\ \(a(n + 1)\) + 
        2\ \(a(n + 2)\) == 0\)], "Output"]
}, Open  ]],

Cell["\<\
And its solution will yield a recursion relation that will allow us \
to compute the coefficients of the original power series, once the first two \
are given.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Solve[eqRecur\ , a[n + 2]]\)[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{a(n + 2) \[Rule] 
        \(-\(\(\(-2\)\ n\ \(a(n)\) - 3\ \(a(n)\) - 6\ n\ \(a(n + 1)\) - 
                6\ \(a(n + 1)\)\)\/\(n\^2 + 3\ n + 2\)\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = % /. n -> n - 2 // Simplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{a(n) \[Rule] 
        \(\((2\ n - 1)\)\ \(a(n - 2)\) + 
            6\ \((n - 1)\)\ \(a(n - 1)\)\)\/\(\((n - 1)\)\ n\)}\)], "Output"]
}, Open  ]],

Cell["\<\


This will help in computing the coefficients\
\>", "Text"],

Cell[BoxData[
    \(Clear[a, expr]; \nexpr[n_] = a[n] /. sol; \n
    a[n_] := \(a[n] = expr[n]\)\)], "Input"],

Cell["\<\
Once the first two are set, the subsequent ones are automatically \
computed and stored.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(a[0] = 1; a[1] = 1; \nTable[a[n], {n, 0, 10}]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{1, 1, 9\/2, 59\/6, 139\/8, 1011\/40, 1519\/48, 19571\/560, 
      155401\/4480, 1265113\/40320, 10543297\/403200}\)], "Output"]
}, Open  ]],

Cell["\<\
Here's a truncated form of a particular solution with a[0]=a[1]=1. \
We must remember to enable the built-in Sum evaluation when we compute the \
sum, lest we incur in an infinite recursion\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(yp = Sum[a[n] x^n, {n, 0, 10}] // EnableSumEvaluation\), 
    \(\(Plot[Evaluate[N[yp]], {x, \(- .5\),  .5}]; \)\)}], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`\(10543297\ x\^10\)\/403200 + \(1265113\ x\^9\)\/40320 + 
      \(155401\ x\^8\)\/4480 + \(19571\ x\^7\)\/560 + \(1519\ x\^6\)\/48 + 
      \(1011\ x\^5\)\/40 + \(139\ x\^4\)\/8 + \(59\ x\^3\)\/6 + 
      \(9\ x\^2\)\/2 + x + 1\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Two trivial typesetting applications", "Section"],

Cell[CellGroupData[{

Cell["A step by step illustration of the perturbation method", "Subsection"],

Cell["\<\
As shown before, it is easy to write the simplifications needed to \
find the sum of the geometric progression by means of the perturbation \
method. Suppose we want to invert the lhs and rhs of every eqautions before \
adding them to a handout. We can do that by just inverting the starting \
equations and re-running the code for the simplification steps. By executing \
this cell \
\>", "Text"],

Cell[BoxData[{
    \(eq = Sum[x\^k, {k, 0, n + 1}] == S\_n + x\^\(n + 1\)\), 
    \(eq = SumSplit[eq, 1]\), 
    \(eq = SumIndexAlign[eq, {k, 0}]\), 
    \(eq = BringOut[eq, x]\), 
    \(eq = eq /. Sum[x^k, {k, 0, n}] \[Rule] S\_n\), 
    \(Solve[eq, S\_n]\)}], "Input"],

Cell[TextData[{
  "we get all the output we need.We can now copy and paste the various steps \
in the text avoiding the manual rewriting of every equation. By converting \
every cell to text and then to traditional form, and by substituting the \
double equal of the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " syntax we can get a pleasant looking set of equations that can be \
interspersed with text. The result is this:"
}], "Text"],

Cell[TextData[{
  "We start by perturbing the sum ",
  Cell[BoxData[
      FormBox[
        TagBox[\(S\_n = \[Sum]\+\(k = 0\)\%n x\^k\),
          HoldForm], TraditionalForm]]],
  " , incrementing its endpoint. We can then write the perturbed form in \
terms of the original sum, whose value we wish to compute:"
}], "Text",
  CellMargins->{{90.375, Inherited}, {Inherited, Inherited}},
  FontSlant->"Italic"],

Cell[BoxData[
    FormBox[
      RowBox[{"\t", 
        RowBox[{
          TagBox[\(\[Sum]\+\(k = 0\)\%\(n + 1\)x\^k\),
            HoldForm], "=", \(x\^\(n + 1\) + S\_n\)}]}], TraditionalForm]], 
  "Text",
  CellMargins->{{90.375, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "What we need to do now is trying to find ",
  Cell[BoxData[
      \(TraditionalForm\`S\_n\)]],
  "in the lhs of this equation. Let's take the first term out of the sum, to \
begin with"
}], "Text",
  CellMargins->{{90.375, Inherited}, {Inherited, Inherited}},
  FontSlant->"Italic"],

Cell[BoxData[
    FormBox[
      RowBox[{"\t", 
        RowBox[{
          RowBox[{
            TagBox[\(\[Sum]\+\(k = 1\)\%\(n + 1\)x\^k\),
              HoldForm], "+", "1"}], "=", \(x\^\(n + 1\) + S\_n\)}]}], 
      TraditionalForm]], "Text",
  CellMargins->{{90.375, Inherited}, {Inherited, Inherited}}],

Cell["\<\
If we now shift the index by 1, we find a form that resembles the \
initial sum.\
\>", "Text",
  CellMargins->{{90.375, Inherited}, {Inherited, Inherited}},
  FontSlant->"Italic"],

Cell[BoxData[
    FormBox[
      RowBox[{"\t", 
        RowBox[{
          RowBox[{
            TagBox[\(\[Sum]\+\(k = 0\)\%n x\^\(k + 1\)\),
              HoldForm], "+", "1"}], "=", \(x\^\(n + 1\) + S\_n\)}]}], 
      TraditionalForm]], "Text",
  CellMargins->{{90.375, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Factoring x out of the sum yields what we were looking for: the \
geometric sum has made its appearance in the left hand side of the equation\
\
\>", "Text",
  CellMargins->{{90.375, Inherited}, {Inherited, Inherited}},
  FontSlant->"Italic"],

Cell[BoxData[
    FormBox[
      RowBox[{"\t", 
        RowBox[{
          RowBox[{
            RowBox[{"x", " ", 
              TagBox[\(\[Sum]\+\(k = 0\)\%n x\^k\),
                HoldForm]}], "+", "1"}], "=", \(x\^\(n + 1\) + S\_n\)}]}], 
      TraditionalForm]], "Text",
  CellMargins->{{90.375, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TraditionalForm\`\(\tx\ S\_n + 1 = x\^\(n + 1\) + S\_n\)\)], "Text",
  CellMargins->{{90.375, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "It is then trivial to find its value by solving for ",
  Cell[BoxData[
      \(TraditionalForm\`S\_n\)]],
  "."
}], "Text",
  CellMargins->{{90.375, Inherited}, {Inherited, Inherited}},
  FontSlant->"Italic"],

Cell[BoxData[
    \(TraditionalForm\`\(\tS\_n = \(x\^\(n + 1\) - 1\)\/\(x - 1\)\)\)], "Text",\

  CellMargins->{{90.375, Inherited}, {Inherited, Inherited}}],

Cell["\<\
This is a very trivial example and could have easily be input by \
handtyping every formula. But when expressions begin to be fairly complicated \
and nontrivial simplification occurs, such as in the demonstration \
application of the power series method to ordinary differential equations, \
the method can significantly reduce the time required and the probability of \
a typo.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Sums of three elements in compact form: vectors in Euclidean spaces \
(*)\
\>", "Subsection"],

Cell[TextData[{
  "When Summa.m is loaded, sums with finite numeric (integer, to be exact) \
endpoints are evaluated in the standard way by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". This could lead to the impossibility to manipulate a certain kind of \
sum. For example, consider the decomposition of a vector into its cartesian \
components in a three-dimensional Euclidean space. This is what we get if we \
input the following sum in a fresh ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session (or immediately after loading Summa.m):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[\(x\_j\) \[DoubleStruckU]\_j, {j, 1, 3}]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`x\_1\ \[DoubleStruckU]\_1 + x\_2\ \[DoubleStruckU]\_2 + 
      x\_3\ \[DoubleStruckU]\_3\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Which is, most of the time, a desirable behavior. But what if we want to \
perform some operations on the vector in its closed form? We should disable \
automatic evaluation of sums with integer endpoints. Option \
Extent\[Rule]Numeric has been introduced in DisableSumEvaluation and \
EnableSumEvaluation to do just that. By disabling sum evaluation with \
Extent->Numeric (or with Extent->All) we prevent every form of  'sum \
takeover' by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s evaluator. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DisableSumEvaluation[Extent \[Rule] Numeric]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`"From now on Summa objects with numerical endpoints  will not be \
evaluated by Mathematica. This will affects Sums  only if their evaluation \
has already been inhibited."\)], "Print"]
}, Open  ]],

Cell[TextData[{
  "If we input the above sum now, we will see that it will be converted to a \
Summa object that won't be evaluated until the user explicitly enables the \
evaluation process. This means that it will be possible to manipulate the sum \
as if it were a symbolic or infinite sum. For example this is a timedependent \
vector r[t] that describes a curve in the three dimensional space with \
versors ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckU]\_j\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(r = Sum[x\_j[t] \[DoubleStruckU]\_j, {j, 1, 3}]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[\(\[Sum]\+\(j = 1\)\%3 \[DoubleStruckU]\_j\ x\_j[t]\),
        HoldForm], TraditionalForm]], "Output"]
}, Open  ]],

Cell["And this is the representation of the tangent vector.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SumD[r, t]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{\(\[Sum]\+\(j = 1\)\%3\), 
          RowBox[{\(\[DoubleStruckU]\_j\), " ", 
            RowBox[{
              SubsuperscriptBox["x", "j", "\[Prime]",
                MultilineFunction->None], "(", "t", ")"}]}]}],
        HoldForm], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Enabling and disabling sum evaluation can be used to build \
traditional form expression with standard mma syntax. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(expr = Sqrt[Sum[x\_j^2, {j, 1, 3}]]; \n
    expr == EnableSumEvaluation[expr]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SqrtBox[
          FormBox[
            TagBox[\(\[Sum]\+\(j = 1\)\%3 x\_j\%2\),
              HoldForm],
            "TraditionalForm"]], "==", 
        \(\@\(x\_1\%2 + x\_2\%2 + x\_3\%2\)\)}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Again this example is outrageously trivial. But with fairly \
complicated expression, the user can save him or herself a considerable \
amount of retyping.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FourierCoefficients", "Section"],

Cell[TextData[{
  "What follows has shown to be a computation that can change depending on \
the version of ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "used, due to the different implementations of Integrate and Simplify  (and \
probably of Coefficient), I guess. If it won't work in your version, it's \
probably because these functions have been made too smart. This is the result \
obtained with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " version 3."
}], "SmallText",
  FontSlant->"Italic"],

Cell["\<\
The Fourier series of a function f[x] can be given in terms of Sin \
and Cos functions:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fourierSum[x_] = 
      a\_0 + Sum[\(a\_n\) Cos[n\ x] + \(b\_n\) Sin[n\ x], {n, 1, \[Infinity]}]
          \)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(a\_0\), "+", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(n = 1\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], 
              \((\(cos(n\ x)\)\ a\_n + \(sin(n\ x)\)\ b\_n)\)}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "To find the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`a\_0\)]],
  ", an and bn we rely upon the orthogonality property of  such  functions:  \
the scalar product with  the corresponding function of index  m  will set to \
zero every term except the one of index m. In this case the scalar product is \
an integral from -\[Pi] to +\[Pi] of the product of the functions. Using \
IntegrateSum instead of Integrate willl allow to thread the operation over \
the whole equation"
}], "Text"],

Cell[TextData[{
  StyleBox["Computing ",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`a\_0\)]]
}], "Text"],

Cell[TextData[{
  "To find ",
  Cell[BoxData[
      \(TraditionalForm\`a\_0\)]],
  " we compute the scalar product with Cos[0 x]=1, that is to say we just \
need to integrate over the interval -\[Pi]__\[Pi]"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SumIntegrate[f[x] == fourierSum[x], {x, \(-\[Pi]\), \[Pi]}] // Simplify
      \)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\[Integral]\_\(-\[Pi]\)\%\[Pi]\( f(x)\) \[DifferentialD]x\), "==", 
        RowBox[{\(2\ \[Pi]\ a\_0\), "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(n = 1\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], 
                \(\(2\ \(sin(n\ \[Pi])\)\ a\_n\)\/n\)}],
              HoldForm],
            "TraditionalForm"]}]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[
"Since n is integer and not zero, we have that Sin[n \[Pi]]/n=0 and thus the \
series in the right hand side is zero. Hence we obtain"], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq1 = % /. Sin[n\ Pi] -> 0 // SumSimplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`\[Integral]\_\(-\[Pi]\)\%\[Pi]\( f(x)\) \[DifferentialD]x == 
      2\ \[Pi]\ a\_0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[eq1, a\_0]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{{a\_0 \[Rule] 
          \(\[Integral]\_\(-\[Pi]\)\%\[Pi]\( f(x)\) \[DifferentialD]x\)\/\(2\ 
              \[Pi]\)}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Computing ",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`a\_m\)],
    FontWeight->"Bold"],
  StyleBox["(m\[GreaterEqual]1)",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[
"To find the coefficients am, with m\[GreaterEqual]1 we compute the scalar \
product with Cos[m x]"], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SumIntegrate[f[x] Cos[m\ x] == fourierSum[x] Cos[m\ x], \n
        \t\t\t{x, \(-\[Pi]\), \[Pi]}] // FullSimplify\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\[Integral]\_\(-\[Pi]\)\%\[Pi]\(\( cos(m\ x)\)\ \(f(x)\)\) 
            \[DifferentialD]x\), "==", 
        RowBox[{\(\(2\ \(sin(m\ \[Pi])\)\ a\_0\)\/m\), "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(n = 1\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], 
                \(\((\(sin(\((m - n)\)\ \[Pi])\)\/\(m - n\) + 
                      \(sin(\((m + n)\)\ \[Pi])\)\/\(m + n\))\)\ a\_n\)}],
              HoldForm],
            "TraditionalForm"]}]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[
"The first term on the right hand side is  zero. The same is true for the \
terms in the series with n\[NotEqual]m, since they are sinuses of multiples \
of \[Pi] divided by non zero quantities.We are left with just one term: the \
one with n=m which can be extracted with SumToTerm (that simply returns the \
general element inside Summa) . Since m+n is nonzero we have no problems in \
getting rid of the part with Sin[(n+m)\[Pi]]. "], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq1 = 
      \(SumToTerm[%] /. Sin[m\ \[Pi]] -> 0\) /. Sin[\((m + n)\)\ Pi] -> 0\)], 
  "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`\[Integral]\_\(-\[Pi]\)\%\[Pi]\(\( cos(m\ x)\)\ \(f(x)\)\) 
          \[DifferentialD]x == 
      \(\(sin(\((m - n)\)\ \[Pi])\)\ a\_n\)\/\(m - n\)\)], "Output"]
}, Open  ]],

Cell[TextData[
"We can't do the same for the Sin[(m-n)\[Pi]]/(m-n) part. We have to take a \
limit:"], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq2 = 
      eq1[\([1]\)] == Limit[eq1[\([2]\)] /. m - n -> z, z -> 0] /. n -> m\)], 
  "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`\[Integral]\_\(-\[Pi]\)\%\[Pi]\(\( cos(m\ x)\)\ \(f(x)\)\) 
          \[DifferentialD]x == \[Pi]\ a\_m\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "and then we can solve for ",
  Cell[BoxData[
      \(TraditionalForm\`a\_m\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[%, a\_m]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{{a\_m \[Rule] 
          \(\[Integral]\_\(-\[Pi]\)\%\[Pi]\(\( cos(m\ x)\)\ \(f(x)\)\) 
                \[DifferentialD]x\)\/\[Pi]}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Computing ",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`b\_m\)],
    FontWeight->"Bold"],
  StyleBox["(m\[GreaterEqual]1)",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  "In the same way we can find the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`b\_m\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SumIntegrate[f[x] Sin[m\ x] == fourierSum[x] Sin[m\ x], \n
        \t\t\t{x, \(-\[Pi]\), \[Pi]}] // FullSimplify\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\[Integral]\_\(-\[Pi]\)\%\[Pi]\(\( f(x)\)\ \(sin(m\ x)\)\) 
            \[DifferentialD]x\), "==", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(n = 1\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], 
              \(\((\(sin(\((m - n)\)\ \[Pi])\)\/\(m - n\) - 
                    \(sin(\((m + n)\)\ \[Pi])\)\/\(m + n\))\)\ b\_n\)}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq1 = SumToTerm[%] /. Sin[\((m + n)\)\ Pi] -> 0\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`\[Integral]\_\(-\[Pi]\)\%\[Pi]\(\( f(x)\)\ \(sin(m\ x)\)\) 
          \[DifferentialD]x == 
      \(\(sin(\((m - n)\)\ \[Pi])\)\ b\_n\)\/\(m - n\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq2 = 
      eq1[\([1]\)] == Limit[eq1[\([2]\)] /. m - n -> z, z -> 0] /. n -> m\)], 
  "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`\[Integral]\_\(-\[Pi]\)\%\[Pi]\(\( f(x)\)\ \(sin(m\ x)\)\) 
          \[DifferentialD]x == \[Pi]\ b\_m\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[%, b\_m]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{{b\_m \[Rule] 
          \(\[Integral]\_\(-\[Pi]\)\%\[Pi]\(\( f(x)\)\ \(sin(m\ x)\)\) 
                \[DifferentialD]x\)\/\[Pi]}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Integrating by series, through differentiation", "Section"],

Cell["\<\
This is an interesting example that emerged from some notes I took \
years ago. It shows how to compute an integral by means of the series \
integration theorem, but the closed form actually found is obtained by means \
of the series differentiation theorem. Since we do not want Mathematica to \
mess with our integrals, producing its output, we define here an overriden \
version of integrate, that does essentialy nothing, and act as a wrapper. The \
code to do that in included in the appendix to this section.\
\>", "Text"],

Cell["\<\
Here is the integral to compute, for a generic value of the real \
parameter z:\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\t
    F\ \((z)\) = 
      \[Integral]\_\(-\(1\/2\)\)\%\(+
            \(1\/2\)\)\(\[ExponentialE]\^\(z\ x\)\/\(1 - x\)\) 
          \[DifferentialD]x\)\)], "Text"],

Cell[TextData[{
  "The integrand is continuos and bounded for every value of z and for x\
\[NotEqual]1. We can find a series equivalent of the integrand function by \
observing that when \[VerticalSeparator]x\[VerticalSeparator]<1 the function \
1/(1-x) is the sum of the geometric series ",
  Cell[BoxData[
      FormBox[
        TagBox[
          RowBox[{
            UnderoverscriptBox["\[Sum]", \(k = 0\), 
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]]], \(x\^k\)}],
          HoldForm], TraditionalForm]]],
  ". We can then write our integral as"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(step1 = 
      Integrate[Exp[z\ x] Sum[x^k, {k, 0, \[Infinity]}], {x, \(-1\)/2, 1/2}]
        \)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Integral]\_\(-\(1\/2\)\)\%\(1\/2\)\), 
        RowBox[{
          RowBox[{\(\[ExponentialE]\^\(x\ z\)\), " ", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", \(k = 0\), 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]], \(x\^k\)}],
                HoldForm],
              "TraditionalForm"]}], \(\[DifferentialD]x\)}]}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
We can bring the exponential factor inside the sum with index k. \
The functions of the resulting series are bounded over the interval of \
integration, and the convergence in uniform.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(step2 = step1 // BringIn\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Integral]\_\(-\(1\/2\)\)\%\(1\/2\)\), 
        RowBox[{
          RowBox[{"(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", \(k = 0\), 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]], 
                  \(\[ExponentialE]\^\(x\ z\)\ x\^k\)}],
                HoldForm],
              "TraditionalForm"], ")"}], \(\[DifferentialD]x\)}]}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
It is then possible to integrate by series, thus reducing the \
integral of the series to the series of integrals of the functions. If we \
disable the builtin integration routine, we can go a little bit farther on \
our own. Exchanging the signs of integration and summation we get\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \($EnableIntegrate = False; \n
    step3 = step2\  /. 
        Integrate[Sum[el_, it_], d_] \[RuleDelayed] 
          Sum[Integrate[el, d], it]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", \(k = 0\), 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]], 
          FormBox[
            
            TagBox[\(\[Integral]\_\(-
                    \(1\/2\)\)\%\(1\/2\)\(\[ExponentialE]\^\(x\ z\)\ x\^k\) 
                  \[DifferentialD]x\),
              HoldForm],
            "TraditionalForm"]}],
        HoldForm], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "We could have left ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " compute the integrals"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{"\t", 
        RowBox[{\(\(\[ScriptCapitalI]\_k\)(z)\), "\[AlignmentMarker]", "=", 
          
          FormBox[\(\[Integral]\_\(-
                  \(1\/2\)\)\%\(1\/2\)\(\[ExponentialE]\^\(x\ z\)\ x\^k\) 
                \[DifferentialD]x\),
            "TraditionalForm"]}]}], TraditionalForm]], "Text",
  TextAlignment->AlignmentMarker],

Cell["\<\
 for us, but there is a neater form for the results that can be \
achieved by considering that\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{"\t", 
        RowBox[{
          RowBox[{
          \(\[PartialD]\(\(\[ScriptCapitalI]\_k\)(z)\)\/\[PartialD]z\), 
            "\[AlignmentMarker]", "=", 
            
            FormBox[\(\(\[PartialD]\/\[PartialD]z\) 
                \(\[Integral]\_\(-
                      \(1\/2\)\)\%\(1\/2\)\(\[ExponentialE]\^\(x\ z\)\ x\^k\) 
                    \[DifferentialD]x\)\),
              "TraditionalForm"]}], "\[IndentingNewLine]", 
          "\[AlignmentMarker]", 
          RowBox[{"=", 
            RowBox[{
              
              FormBox[\(\[Integral]\_\(-
                      \(1\/2\)\)\%\(1\/2\)\(\[PartialD]\/\[PartialD]z\) 
                    \((\[ExponentialE]\^\(x\ z\)\ x\^k)\) 
                    \[DifferentialD]x\),
                "TraditionalForm"], "=", 
              RowBox[{
                
                FormBox[
                  \(\[Integral]\_\(-\(1\/2\)\)\%\(1\/2\)\(x\ 
                        \[ExponentialE]\^\(x\ z\)\ x\^k\) 
                      \[DifferentialD]x\),
                  "TraditionalForm"], "=", 
                
                FormBox[
                  \(\[Integral]\_\(-
                        \(1\/2\)\)\%\(1\/2\)\(\[ExponentialE]\^\(x\ z\)\ 
                        x\^\(k + 1\)\) \[DifferentialD]x\),
                  "TraditionalForm"]}]}]}], "\[IndentingNewLine]", 
          "\[AlignmentMarker]", 
          RowBox[{"=", 
            FormBox[\(\(\[ScriptCapitalI]\_\(k + 1\)\)(z)\),
              "TraditionalForm"]}]}]}], TraditionalForm]], "Text",
  TextAlignment->AlignmentMarker],

Cell["\<\
We can iterate this relation k times to espress the k-th element in \
terms of the 0-th element\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\t
    \(\[ScriptCapitalI]\_k\)(z) = 
      \(\[PartialD]\(\(\[ScriptCapitalI]\_\(k - 1\)\)(z)\)\/\[PartialD]z = 
        \(\[PartialD]\^2\(\( \[ScriptCapitalI]\_\(k - 2\)\)(z)\)\/\[PartialD]z
                \^2 = \(\[PartialD]\^3\(\( \[ScriptCapitalI]\_\(k - 3\)\)(z)
                  \)\/\[PartialD]z\^3 = 
            \(\[Ellipsis] = 
              \(\[PartialD]\^\(k - 1\)\(\(\[ScriptCapitalI]\_1\)(z)
                      \)\/\[PartialD]z\^\(k - 1\) = 
                \[PartialD]\^k\(\( \[ScriptCapitalI]\_0\)(z)\)\/\[PartialD]z
                      \^k\)\)\)\)\)\)\)], "Text"],

Cell[TextData[{
  "Now all we need to compute is the value of the integral for the particular \
case k=0. The integral is so easy it could be done by hand. But we have kept \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " too much time under the carpet, so let's feed it the following:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(lhs = Integrate[Exp[z\ x] x^k /. k \[Rule] 0, {x, \(-1\)/2, 1/2}]; 
    \n$EnableIntegrate = True; \n
    rhs = Integrate[Exp[z\ x] x^k /. k \[Rule] 0, {x, \(-1\)/2, 1/2}] // 
        FullSimplify; \nlhs \[Equal] rhs\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          
          TagBox[\(\[Integral]\_\(-
                  \(1\/2\)\)\%\(1\/2\)\(\[ExponentialE]\^\(x\ z\)\) 
                \[DifferentialD]x\),
            HoldForm],
          "TraditionalForm"], "==", \(\(2\ \(sinh(z\/2)\)\)\/z\)}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["Our integral is thus", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{"\t", 
        RowBox[{\(F\ \((z)\)\), "=", 
          RowBox[{
          \(\[Integral]\_\(-\(1\/2\)\)\%\(+
                  \(1\/2\)\)\(\[ExponentialE]\^\(z\ x\)\/\(1 - x\)\) 
                \[DifferentialD]x\), "=", 
            RowBox[{
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", \(k = 0\), 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]], 
                  FormBox[
                    TagBox[\(\(\[ScriptCapitalI]\_k\)(z)\),
                      HoldForm],
                    "TraditionalForm"]}],
                HoldForm], "=", 
              RowBox[{
                TagBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", \(k = 0\), 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]]], 
                    FormBox[
                      
                      TagBox[\(\[PartialD]\^k\(\( \[ScriptCapitalI]\_0\)(z)
                                \)\/\[PartialD]z\^k\),
                        HoldForm],
                      "TraditionalForm"]}],
                  HoldForm], "=", 
                RowBox[{
                  TagBox[
                    RowBox[{
                      UnderoverscriptBox["\[Sum]", \(k = 0\), 
                        InterpretationBox["\[Infinity]",
                          DirectedInfinity[ 1]]], 
                      FormBox[
                        TagBox[\(\[PartialD]\^k\/\[PartialD]z\^k\),
                          HoldForm],
                        "TraditionalForm"]}],
                    HoldForm], \(\(sinh(z/2)\)\/\(z/2\)\)}]}]}]}]}]}], 
      TraditionalForm]], "Text"],

Cell["\<\
And it seems to be suffering from poor numerical stability near \
z=0.\
\>", "Text"],

Cell[BoxData[
    \(F[z_] = Sum[2\ D[Sinh[z/2]/z, {z, k}], {k, 0, 50}]; \n
    Plot[F[z], {z, 10, 15}, PlotRange \[Rule] All, Frame \[Rule] True]; \)], 
  "Input"],

Cell[BoxData[
    \(F[z_] = 
      Sum[\ D[\((\[ExponentialE]\^\(z/2\) - \[ExponentialE]\^\(\(-z\)/2\))\)/
            z, {z, k}], {k, 0, 50}]; \n
    Plot[F[z], {z, 10, 15}, PlotRange \[Rule] All, Frame \[Rule] True]; \)], 
  "Input"],

Cell[CellGroupData[{

Cell["Appendix: Code to override Integrate", "Subsubsection"],

Cell[BoxData[{
    \(\($EnableIntegrate = False; \)\), 
    \(\[IndentingNewLine]\), 
    \(\($Auto = False; \)\)}], "Input",
  CellFrame->True,
  InitializationCell->True,
  Background->GrayLevel[0.833326]],

Cell[BoxData[{
    \(\(Unprotect[Integrate]; \)\), 
    \(\n\), 
    \(Integrate[args__ /; $EnableIntegrate \[Equal] False] := 
      \[IndentingNewLine]Block[\[IndentingNewLine]{$EnableIntegrate = True}, 
        \[IndentingNewLine]integrate[args]\[IndentingNewLine]]\), 
    \(\n\), 
    \(\(Protect[Integrate]; \)\)}], "Input",
  CellFrame->True,
  InitializationCell->True,
  Background->GrayLevel[0.833326]],

Cell[BoxData[
    \(Format[integrate[el_, it_]] := 
      \[IndentingNewLine]Block[\[IndentingNewLine]{$EnableIntegrate = True}, 
        \[IndentingNewLine]If[$Auto, \[IndentingNewLine]Integrate[el, it], 
          \[IndentingNewLine]HoldForm[Integrate[el, it]]\[IndentingNewLine]]
          \[IndentingNewLine]]\)], "Input",
  CellFrame->True,
  InitializationCell->True,
  Background->GrayLevel[0.833326]]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1152}, {0, 900}},
WindowToolbars->{},
WindowSize->{696, 756},
WindowMargins->{{72, Automatic}, {Automatic, 55}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "Classroom.nb"]
