Notebook[{
Cell[TextData[{
  "Summa: \n",
  StyleBox["S",
    FontSlant->"Italic",
    FontVariations->{"Underline"->True}],
  "ymbolic s",
  StyleBox["u",
    FontSlant->"Italic",
    FontVariations->{"Underline"->True}],
  StyleBox["m",
    FontSlant->"Italic",
    FontVariations->{"Underline"->True}],
  "s ",
  StyleBox["ma",
    FontSlant->"Italic",
    FontVariations->{"Underline"->True}],
  "nipulation"
}], "Title"],

Cell[TextData[{
  "Avoiding ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s evaluator for symbolic and infinite Sums"
}], "Subtitle"],

Cell["\<\
Package \t\tSumma.m \tVersion\t2.4e
Author: \t\tPeltio (peltio@despammed.com)
Development \tinitially on 2.2.1, refined on 3.0 and 4.x
Date\t\t\tMarch 2005
Disclaimer\t\teverybody is free to use and modify the package provided that
\t\t\t-the original author information is left intact
\t\t\t-corrections and enhancements will be as free as this package and, \
possibly, sent to the author
\t\t\tVersion 2.4e of the package Summa.m contains slightly different \
procedures of those herein described.\
\>", "Copyright"],

Cell[TextData[{
  "The purpose of this notebook is to show how the functionalities of Summa.m \
were implemented. The package defines an abstract object ",
  StyleBox["Summa",
    FontWeight->"Bold"],
  " (intended as a version of Sum that does not evaluate) and several \
procedures to manipulate expression containg such object. Since version 2 of \
the package, the user is allowed to disable and enable the ordinary Sum \
evaluation process either locally or globally, by automatically converting  \
every Sum into a Summa object or vice versa. By disabling Sum evaluation, \
every Sum is automatically converted into a Summa object before being fed to \
the evaluator: this approach allows the user to apply  manipulation routines \
developed for Summas directly to built-in Sums. Most of this notebook was \
written for an earlier version of Summa.m; even though additions were made as \
long as new functionalities were added to the package,  some of the functions \
herein described can have a slightly different implementation in the latest \
available version of the package.A new alternate naming has been added in \
order to have most functions acting on Sums begin with Sum* (notable \
exception are BringIn and BringOut)."
}], "Text"],

Cell[CellGroupData[{

Cell["Overriding Sum", "Section"],

Cell["\<\
The main change introduced with version 2 of this package is the \
ability to address Summa objects with exactly the same input syntax used for \
built-in Sums. In the rest of this notebook we will address, somewhat \
loosely, this behavior by \"enabling and disabling the Sum evaluation process\
\". The built-in evaluation process is not actualy being inhibithed: it just \
doesn't have a chance to see Sums anymore unless the user sets a specific \
environment variable that suppresses the conversions of Sum into Summa. \
Please refer to the notebook \"Basic Overriding\" for further information on \
this subject. A rather extensive notebook on the subject, along with a \
package that automates the generation of the code neeeded to override a \
built-in procedure or object is currently under development.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Overriding Sum", "Subsection"],

Cell[TextData[{
  "Let's see how the concepts expressed in the \"basic overriding\" notebook \
apply to Sum: first thing first we redefine Sum in terms of the user defined \
object Summa. We give our 'enabling' flag a unique name: ",
  StyleBox["$EnableSumEvaluation",
    FontWeight->"Bold"]
}], "Text"],

Cell[BoxData[
    \($EnableSumEvaluation = False; \nProtect[$EnableSumEvaluation]; \)], 
  "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[BoxData[{
    \(Unprotect[Sum]; \n
    Sum[args__ /; $EnableSumEvaluation \[Equal] False] := 
      \[IndentingNewLine]Block[
        \[IndentingNewLine]{$EnableSumEvaluation = True}, 
        \[IndentingNewLine]Summa[args]\[IndentingNewLine]]\), 
    \(\(Protect[Sum]; \)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["\<\
Since we haven't written any code for Summa yet, calls to Sum will \
be diverted to an unevaluated Summa that simply acts as a wrapper: Note that \
this definitiom  will inhibit multiple sums evaluation too. At present, \
though, the package does not allow multiple dimensional sum manipulation, \
except for very simple nested sums. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Sum[x\_k, {k, 2, \[Infinity]}], Sum[x\_k, {k, 2, 7}], 
      Sum[x\_k, {k, 5}], Sum[\(a\_j\) x\_j\^k, {j, 3}, {k, 0, 2}]}\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Summa", "(", 
            RowBox[{\(x\_k\), ",", 
              RowBox[{"{", 
                RowBox[{"k", ",", "2", ",", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]}], "}"}]}], ")"}], ",", 
          \(Summa(x\_k, {k, 2, 7})\), ",", \(Summa(x\_k, {k, 5})\), ",", 
          \(Summa(a\_j\ x\_j\%k, {j, 3}, {k, 0, 2})\)}], "}"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Later on we will write a code that leads to an unevaluated wrapper \
when the endpoints are either infinite or symbolic, but calls to the the \
built-in function Sum when both endpoints are integers. This is possibile \
because the call to Summa, when we input a Sum object, take place inside a \
Block with $EnableSumEvaluation=True. 
When $EnableSumEvaluation is set to False every instance of Sum is \
automatically converted to a Summa object. Hence, we can write the code for \
our symbolic maipulation functions just in terms of Summa. For example, the \
folowing function, that relies on replacement rules to bring a common factor \
out of the wrapper can be applied to Summa object, of course, but will work \
even when it is applied to a Sum :\
\>", "Text"],

Cell[BoxData[
    \(outrule1 = {
        \[IndentingNewLine]Summa[f_ + g_, it : {k_Symbol, __}] \[RuleDelayed] 
          Summa[f, it] + Summa[g, it], 
        \[IndentingNewLine]Summa[c_\ f_, it : {k_Symbol, __}] \[RuleDelayed] 
          c\ Summa[f, it] /; FreeQ[c, k]\[IndentingNewLine]}; \n
    outrule2 = 
      Summa[c_, it : {k_Symbol, __}] \[RuleDelayed] 
        c\ Summa[1, it] /; FreeQ[c, k]; \n
    outrules = Flatten[{outrule1, outrule2}]; \n
    BringOut[s_] := s //. outrules\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BringOut[Summa[a\ k\ x\_k, {k, 2, \[Infinity]}]]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"a", " ", 
        RowBox[{"Summa", "(", 
          RowBox[{\(k\ x\_k\), ",", 
            RowBox[{"{", 
              RowBox[{"k", ",", "2", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}]}], ")"}]}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BringOut[Sum[a\ k\ x\_k, {k, 2, \[Infinity]}]]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"a", " ", 
        RowBox[{"Summa", "(", 
          RowBox[{\(k\ x\_k\), ",", 
            RowBox[{"{", 
              RowBox[{"k", ",", "2", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}]}], ")"}]}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
We will delve into these functions with more details later on. For \
the time being, let's focus on the conversion between Summa and Sum\
\>", 
  "Text"],

Cell[CellGroupData[{

Cell["A step further: overriding nested sums", "Subsubsection"],

Cell[TextData[{
  "Nested sums pose a problem.When the Block structure is applied to the \
outer sum, those that appen to be inside it are evaluated as if they were \
ordinary ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " sums; in fact they fall under the scope of Block with \
$EnableSumEvaluation=True.Here's an example"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[Sum[a[j] a[k], {j, 1, n}], {k, 1, n}]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`Summa(\[Sum]\+\(j = 1\)\%n\( a(j)\)\ \(a(k)\), {k, 1, n})\)], "Output"]
}, Open  ]],

Cell["\<\
We can try to fix this by using a second Block that enclosed the \
arguments of every sum.This is the new version of the code\
\>", "Text"],

Cell[BoxData[{
    \(Unprotect[Sum]; \nClear[Sum]; \n
    Sum[args__] /; $EnableSumEvaluation \[Equal] False := 
      Block[{$EnableSumEvaluation = True}, 
        \[IndentingNewLine]Summa[
          \[IndentingNewLine]Sequence@@
            Block[\[IndentingNewLine]{$EnableSumEvaluation = False}, 
              \[IndentingNewLine]tmp[args]]]\[IndentingNewLine]]\), 
    \(\(Protect[Sum]; \)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["It seems to work", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[Sum[Sum[el, it1], it2], it3]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`Summa(Summa(Summa(el, it1), it2), it3)\)], "Output"]
}, Open  ]],

Cell["We can work some simplification, too", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[Sum[a[j] a[k], {j, 1, n}], {k, 1, n}]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`Summa(Summa(\(a(j)\)\ \(a(k)\), {j, 1, n}), {k, 1, n})\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% // BringOut\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`\(Summa(a(j), {j, 1, n})\)\ \(Summa(a(k), {k, 1, n})\)\)], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Enabling and disabling Sum evaluation", "Subsection"],

Cell["\<\
If we set the global variable $enablebuiltin to True, we can access \
to the builtin form of Sum, and still be able to access to the user defined \
code for Summa\
\>", "Text"],

Cell[BoxData[
    \(Unprotect[$EnableSumEvaluation]; \n$EnableSumEvaluation = True; \n
    Protect[$EnableSumEvaluation]; \)], "Input"],

Cell["Summa objects work as usual ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Summa[a/k^2, {k, 1, \[Infinity]}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"Summa", "(", 
        RowBox[{\(a\/k\^2\), ",", 
          RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", 
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]]}], "}"}]}], ")"}], TraditionalForm]], 
  "Output"]
}, Open  ]],

Cell["\<\
And so do Sums, according to the predefined Mathematica behaviour\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[a/k^2, {k, 1, \[Infinity]}]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(a\ \[Pi]\^2\)\/6\)], "Output"]
}, Open  ]],

Cell["\<\
We can write a couple of procedures that unprotect and protect the \
environment variable for us.\
\>", "Text"],

Cell[BoxData[{
    \(\ EnableSumEvaluation[] := 
      \[IndentingNewLine]\((
        \[IndentingNewLine]Unprotect[$EnableSumEvaluation]; 
        \[IndentingNewLine]$EnableSumEvaluation = True; 
        \[IndentingNewLine]Protect[$EnableSumEvaluation]; \[IndentingNewLine])
        \)\[IndentingNewLine]\), 
    \(DisableSumEvaluation[] := 
      \[IndentingNewLine]\((
        \[IndentingNewLine]Unprotect[$EnableSumEvaluation]; 
        \[IndentingNewLine]$EnableSumEvaluation = False; 
        \[IndentingNewLine]Protect[$EnableSumEvaluation]; \[IndentingNewLine])
        \)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["\<\
Moreover, we can make this process localized to a single \
expression, regardless of the value of the environment variable \
$EnableSumEvaluation. For example, to locally enable Sum evaluation, we can \
let a procedure substitute every occurence of Summa with Sum when the built\
\[IGrave]in evaluation is turned on and replacing the surviving Sums with \
Summa prior to outputting the result in an environment where the built-in sum \
evaluaton is disabled. We must give this procedure the attibute Holdfirst to \
avoid the evaluation of the expression passed\
\>", "Text"],

Cell[BoxData[{
    \(\ \(Attributes[EnableSumEvaluation] = {HoldFirst}; \)\), 
    \(EnableSumEvaluation[expr_] := 
      \[IndentingNewLine]\((\[IndentingNewLine]EnableSumEvaluation[]; 
        \[IndentingNewLine]First[{expr /. Summa \[Rule] Sum, 
              DisableSumEvaluation[]}] /. 
          Sum \[Rule] Summa\[IndentingNewLine])\)\[IndentingNewLine]\), 
    \(\(Attributes[DisableSumEvaluation] = {HoldFirst}; \)\), 
    \(DisableSumEvaluation[expr_] := 
      \[IndentingNewLine]\((\[IndentingNewLine]DisableSumEvaluation[]; 
        \[IndentingNewLine]First[{expr /. Sum \[Rule] Summa, 
              EnableSumEvaluation[]}] /. Summa \[Rule] Sum\[IndentingNewLine])
        \)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["\<\
Here we use First to give back a result after the last eleement of \
the list has been evaluated. 
The procedures implemented in the package are slightly different and have \
options to make them more flexible (the can print a warning message and leave \
the built-in evaluation process on or off once the expression has been \
returned). See the notebook 'Usage of Summa' for more information on these \
procedures and when to use them. 
Before we continue we must override ordinary sum evaluation with our own \
procedure:\
\>", "Text"],

Cell[BoxData[
    \(DisableSumEvaluation[]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Enabling and disabling Sum enhancements (*)", "Subsection"],

Cell["To be added in the next major version.", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Defining the Abstract Object Summa", "Section"],

Cell["Summa[el,{x,n1,n2}]", "Definition"],

Cell[CellGroupData[{

Cell["Definition", "Subsection"],

Cell["\<\
We definine a Summa object in such a way that it will not be \
evaluated unless both the start and end values of the index are numerical \
(integers, to be precise). In the latter case it will be evaluated as a \
built-in Sum. This is the idea:\
\>", "Text"],

Cell[BoxData[
    \(Summa[el_, {k_Symbol, k0_Integer, k1_Integer}] := 
      Sum[el, {k, k0, k1}]\)], "Input"],

Cell["\<\
And this is the implementation that works for multidimensional sums \
as well, regardless of the form used for the iterators:\
\>", "Text"],

Cell[BoxData[
    \(Summa[el_, 
        it : \(({_Symbol, _Integer, _Integer} | {_Symbol, _Integer})
              \) .. ] := Sum[el, it]\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["\<\
This is what we get at this point for symbolic (or infinite) and \
finite sums\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({f1 = Summa[a\_k\ x^k, {k, 0, \[Infinity]}], 
      Summa[a\_k\ x^k, {k, \[Infinity]}], Summa[x^k, {k, n}]}\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Summa", "(", 
            RowBox[{\(x\^k\ a\_k\), ",", 
              RowBox[{"{", 
                RowBox[{"k", ",", "0", ",", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]}], "}"}]}], ")"}], ",", 
          RowBox[{"Summa", "(", 
            RowBox[{\(x\^k\ a\_k\), ",", 
              RowBox[{"{", 
                RowBox[{"k", ",", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]}], "}"}]}], ")"}], ",", 
          \(Summa(x\^k, {k, n})\)}], "}"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({s1 = Summa[a\_k\ x^k, {k, 0, 4}], Summa[a\_k\ x^k, {k, 4}], 
      Summa[x^k, {k, 2}]}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{a\_4\ x\^4 + a\_3\ x\^3 + a\_2\ x\^2 + a\_1\ x + a\_0, 
      a\_4\ x\^4 + a\_3\ x\^3 + a\_2\ x\^2 + a\_1\ x, x\^2 + x}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Oh, and what about sums with multiple indices? In order to be evaluated as \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Sums, ",
  StyleBox["every",
    FontSlant->"Italic"],
  " iterator should have integer endpoints:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \({Sum[\(a\_k\) x\_k\^j, {k, \[Infinity]}, {j, 1, 2}], 
      Sum[\(a\_k\) x\_k\^j, {k, 3}, {j, 1, n}]}\), 
    \({Sum[\(a\_k\) x\_k\^j, {k, 3}, {j, 1, 2}]}\)}], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"Summa", "(", 
            RowBox[{\(a\_k\ x\_k\%j\), ",", 
              RowBox[{"{", 
                RowBox[{"k", ",", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]}], "}"}], ",", \({j, 1, 2}\)}], 
            ")"}], ",", \(Summa(a\_k\ x\_k\%j, {k, 3}, {j, 1, n})\)}], "}"}], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    \(TraditionalForm
    \`{a\_1\ x\_1\%2 + a\_1\ x\_1 + a\_2\ x\_2\%2 + a\_3\ x\_3\%2 + 
        a\_2\ x\_2 + a\_3\ x\_3}\)], "Output"]
}, Open  ]],

Cell["\<\

We can add a line to convert the compact iterator form into its full-blown \
equivalent. The following line will take care of any sequence of iterators, \
replacing those with only two elements with their expanded counterparts. A \
condition has to be fullfilled in order to avoid an infinite recursion (we \
are now defining a Summa in terms of itself, so we need something to tell the \
transformed version from the untouched one).\
\>", "Text"],

Cell[BoxData[
    \(Summa[el_, it : \(({_, _} | {_, _, _})\) .. ] /; 
        EvenQ[Times@@\((Map[Length, {it}, \(-1\)])\)] := 
      Summa[el, 
        ReleaseHold[Hold[it] /. \(({k_, k1_} \[RuleDelayed] {k, 1, k1})\)]]
        \)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[CellGroupData[{

Cell[BoxData[
    \({Sum[x\_k, {k, n}], Sum[\(a\_k\) x\_k\^j, {k, 3}, {j, \[Infinity]}]}
      \)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{\(Summa(x\_k, {k, 1, n})\), ",", 
          RowBox[{"Summa", "(", 
            RowBox[{\(a\_k\ x\_k\%j\), ",", \({k, 1, 3}\), ",", 
              RowBox[{"{", 
                RowBox[{"j", ",", "1", ",", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]}], "}"}]}], ")"}]}], "}"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
This definiton will force us to write the call to Summa in a form \
that won't rely on iterators espressed as {k,ks} (even if ks means 'one or \
more elements'), because that form will be immediately reverted to {k,1,ks}. \
We will use the more general form for the iterator and, if necessary, we will \
specify the nature of the first element.\
\>", "Text"],

Cell[BoxData[{
    \(it : {_, _, _}\), 
    \(it : \(({_, _} | {_, _, _})\)\), 
    \(it : \(({_, _} | {_, _, _})\) .. \), 
    \(it : \(({k_, _} | {k_, _, _})\) .. \), 
    \(it : \(({k_Symbol, _} | {k_Symbol, _, _})\) .. \)}], "Input",
  Evaluatable->False],

Cell[CellGroupData[{

Cell["A step further: a switch for sums with numerical endpoints", 
  "Subsubsection"],

Cell["\<\
Since we might want to manipulate sums with numerical endpoints in \
their compact form, without letting mma evaluate them, it may prove useful \
subordinate the trasformation of Summas into Sums to the value of a boolean \
environmental variable. We set the value of this variable to True, by default\
\
\>", "Text"],

Cell[BoxData[
    \(\($EnableNumericSum = True; \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["And add a condition to the definition of Summa", "Text"],

Cell[BoxData[
    \(Summa[el_, 
          it : \(({_Symbol, _Integer, _Integer} | {_Symbol, _Integer})
                \) .. ] /; $EnableNumericSum \[Equal] True := Sum[el, it]\)], 
  "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["\<\
Then we rig the procedures EnableSumEvaluation and \
DisableSumEvaluation with some extra code to set the right value of this \
variable. The code is not shown here, since there is nothing special to it. \
More on this can be found in the Usage notebook.\
\>", "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Output Format(s)", "Subsection"],

Cell["\<\
We might not like the way our redefined sums are displayed. We are \
accustomed to see sums as Sum objects, and on version 3 or later two \
dimensional formatting represents a useful visual aid it would be a pity not \
to use. It seems a good idea to define for Summa  a format similar to that \
used by Sum. Since the function Format needs to call the built-in version of \
Sum, we must enclose such a call inside a Block that sets \
$EnableSumEvaluation to True. \
\>", "Text"],

Cell[BoxData[
    \(Format[Summa[el_, it : {k_Symbol, __}]] := 
      \[IndentingNewLine]Block[{$EnableSumEvaluation = True}, \n\t\t
        Sum[el, it]\[IndentingNewLine]]\)], "Input"],

Cell["\<\
When $EnableSumEvaluation is False,this definition will apply to \
Sums too,since in that case every Sum is automatically transformed into a \
Summa object before it can be evaluated,and then formatted accordingly.\
\>", 
  "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Sum[x\_k, {k, 2, \[Infinity]}], Summa[x\_k, {k, 2, \[Infinity]}], 
      Summa[x\_k, {k, \[Infinity]}]}\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(k = 2\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(x\_k\)}],
              HoldForm],
            "TraditionalForm"], ",", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(k = 2\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(x\_k\)}],
              HoldForm],
            "TraditionalForm"], ",", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(k = 1\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(x\_k\)}],
              HoldForm],
            "TraditionalForm"]}], "}"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(InputForm[%]\)], "Input"],

Cell["\<\
{Summa[Subscript[x, k], {k, 2, Infinity}], 
  Summa[Subscript[x, k], {k, 2, Infinity}], 
  Summa[Subscript[x, k], {k, 1, Infinity}]}\
\>", "Output"]
}, Open  ]],

Cell[TextData[{
  "There is a shortcoming for this method, though: since the formatting \
results from ",
  StyleBox["Mathematica'",
    FontSlant->"Italic"],
  "s  built-in evaluation of  Sum ",
  StyleBox["(",
    FontSlant->"Italic"],
  "while the sum's true form is a Summa object), every convergent sum known \
to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will be represented as the value toward which the sum actually converges. \
For example, the following sum is known to converge to e, hence it will be \
displayed in this way:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Summa[1/\(k!\), {k, 0, \[Infinity]}]\)], "Input",
  Evaluatable->False],

Cell[BoxData[
    \(TraditionalForm\`\[ExponentialE]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Even if its internal representation is that of an ",
  StyleBox["unevaluated",
    FontSlant->"Italic"],
  " Summa object"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(InputForm[%]\)], "Input",
  Evaluatable->False],

Cell["Summa[k!^(-1), {k, 0, Infinity}]", "Output"]
}, Open  ]],

Cell["\<\
To avoid such idiosyncracies we can wrap HoldForm around Sum. \
Better yet, we can let the user choose whether he wants to see the \
unevaluated or evaluated form of the sums he is working with (so that he can \
see if it is the case to apply the predefined built-in evaluation to certain \
parts of the expression). Switching from one behavior to the other one is \
made by means of the private variable $Auto,  that can be set by the exported \
funtion SetSumFormat. Since we want our procedure to be as general as \
possibile, we also allow for multiple iterators. We don't have to worry about \
mixed iterators (such as {k, a,b} and {k, b}) since that will be taken Our \
code becomes:\
\>", "Text"],

Cell[BoxData[
    \($Auto = True; \n
    Format[Summa[el_, it : {_Symbol, __} .. ]] := 
      \[IndentingNewLine]Block[
        \[IndentingNewLine]{$EnableSumEvaluation = True}, 
        \[IndentingNewLine]If[$Auto, \[IndentingNewLine]Sum[el, it], 
          \[IndentingNewLine]HoldForm[Sum[el, it]]\[IndentingNewLine]]
          \[IndentingNewLine]]\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["\<\
When $Auto is set to False, we can see the unevaluated form of our \
sums\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \($Auto = False; {Summa[x\_k, {k, 2, \[Infinity]}], 
      Summa[1/\(k!\), {k, 0, \[Infinity]}], 
      Summa[1/\(k!\), {k, \[Infinity]}], Sum[\(a\_k\) x\^k, {k, 0, 2}]}\)], 
  "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(k = 2\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(x\_k\)}],
              HoldForm],
            "TraditionalForm"], ",", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(k = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(1\/\(k!\)\)}],
              HoldForm],
            "TraditionalForm"], ",", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(k = 1\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(1\/\(k!\)\)}],
              HoldForm],
            "TraditionalForm"], ",", \(a\_2\ x\^2 + a\_1\ x + a\_0\)}], 
        "}"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "While when it is set to True we see the result of ",
  StyleBox["Mathematica's ",
    FontSlant->"Italic"],
  "evaluation (and sometimes even an error message warning about the non \
convergence of certain sums):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \($Auto = True; {Summa[x\_k, {k, 2, \[Infinity]}], 
      Summa[1/\(k!\), {k, 0, \[Infinity]}], 
      Summa[1/\(k!\), {k, \[Infinity]}], Sum[\(a\_k\) x\^k, {k, 0, 2}]}\)], 
  "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          FormBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 2\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(x\_k\)}],
            "TraditionalForm"], ",", 
          FormBox["\[ExponentialE]",
            "TraditionalForm"], ",", 
          FormBox[\(\(-1\) + \[ExponentialE]\),
            "TraditionalForm"], ",", \(a\_2\ x\^2 + a\_1\ x + a\_0\)}], 
        "}"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
We must keep in mind, though, that the internal representation of \
the sums is still a Summa object\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(InputForm[%]\)], "Input"],

Cell["\<\
{Summa[Subscript[x, k], {k, 2, Infinity}], 
 Summa[k!^(-1), {k, 0, Infinity}], 
 Summa[k!^(-1), {k, 1, Infinity}], 
 Subscript[a, 0] + x*Subscript[a, 1] + 
  x^2*Subscript[a, 2]}\
\>", "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(OutputForm[%%]\)], "Input"],

Cell[OutputFormData["\<\
{Summa[Subscript[x, k], {k, 2, Infinity}], 
 Summa[k!^(-1), {k, 0, Infinity}], 
 Summa[k!^(-1), {k, 1, Infinity}], 
 Subscript[a, 0] + x*Subscript[a, 1] + 
  x^2*Subscript[a, 2]}\
\>", 
"\<\
                                                    2
{Sum[x , {k, 2, Infinity}], E, -1 + E, a  + x a  + x  a }
      k                                 0      1       2\
\>"], "Output"]
}, Open  ]],

Cell["\<\
If we need to convert Sum in Summa or viceversa we must resort to \
EnableBuiltinEvaluation and DisableBuiltinEvaluation. Our formatting can take \
care of multidimensional sums as well.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \($Auto = False; 
    \n{Summa[\(a\_k\) x\_k\^j, {k, 2, \[Infinity]}, {j, 0, 2}], 
        Summa[j, {j, k}, {k, 0, 2}], 
        Summa[\(a\_k\) x\_k\^j, {k, 2}, {j, 0, 2}]} // ColumnForm\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", \(k = 2\), 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]], 
                  \(\[Sum]\+\(j = 0\)\%2 a\_k\ x\_k\%j\)}],
                "TraditionalForm"]},
            {
              FormBox[\(\[Sum]\+\(j = 1\)\%k\(\[Sum]\+\(k = 0\)\%2 j\)\),
                "TraditionalForm"]},
            {
              \(a\_1\ x\_1\%2 + a\_1\ x\_1 + a\_2\ x\_2\%2 + a\_1 + a\_2 + 
                a\_2\ x\_2\)}
            },
          GridBaseline->{Baseline, {1, 1}},
          ColumnAlignments->{Left}],
        ColumnForm[ {
          Summa[ 
            Times[ 
              Subscript[ a, k], 
              Power[ 
                Subscript[ x, k], j]], {k, 2, 
            DirectedInfinity[ 1]}, {j, 0, 2}], 
          Summa[ j, {j, 1, k}, {k, 0, 2}], 
          Plus[ 
            Subscript[ a, 1], 
            Subscript[ a, 2], 
            Times[ 
              Subscript[ a, 1], 
              Subscript[ x, 1]], 
            Times[ 
              Subscript[ a, 1], 
              Power[ 
                Subscript[ x, 1], 2]], 
            Times[ 
              Subscript[ a, 2], 
              Subscript[ x, 2]], 
            Times[ 
              Subscript[ a, 2], 
              Power[ 
                Subscript[ x, 2], 2]]]}],
        Editable->False], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \($Auto = True; 
    \n{Summa[\(a\_k\) x\_k\^j, {k, 2, \[Infinity]}, {j, 0, 2}], 
        Summa[j, {j, k}, {k, 0, 2}], 
        Summa[\(a\_k\) x\_k\^j, {k, 2}, {j, 0, 2}]} // ColumnForm\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", \(k = 2\), 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]], 
                  \(\[Sum]\+\(j = 0\)\%2 a\_k\ x\_k\%j\)}],
                "TraditionalForm"]},
            {
              FormBox[\(3\/2\ k\ \((k + 1)\)\),
                "TraditionalForm"]},
            {
              \(a\_1\ x\_1\%2 + a\_1\ x\_1 + a\_2\ x\_2\%2 + a\_1 + a\_2 + 
                a\_2\ x\_2\)}
            },
          GridBaseline->{Baseline, {1, 1}},
          ColumnAlignments->{Left}],
        ColumnForm[ {
          Summa[ 
            Times[ 
              Subscript[ a, k], 
              Power[ 
                Subscript[ x, k], j]], {k, 2, 
            DirectedInfinity[ 1]}, {j, 0, 2}], 
          Summa[ j, {j, 1, k}, {k, 0, 2}], 
          Plus[ 
            Subscript[ a, 1], 
            Subscript[ a, 2], 
            Times[ 
              Subscript[ a, 1], 
              Subscript[ x, 1]], 
            Times[ 
              Subscript[ a, 1], 
              Power[ 
                Subscript[ x, 1], 2]], 
            Times[ 
              Subscript[ a, 2], 
              Subscript[ x, 2]], 
            Times[ 
              Subscript[ a, 2], 
              Power[ 
                Subscript[ x, 2], 2]]]}],
        Editable->False], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Same ",
  StyleBox["caveat",
    FontSlant->"Italic"],
  " as before:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(InputForm[%]\)], "Input"],

Cell["\<\
Summa[Subscript[a, k]*Subscript[x, k]^j, 
  {k, 2, Infinity}, {j, 0, 2}]
Summa[j, {j, 1, k}, {k, 0, 2}]
Subscript[a, 1] + Subscript[a, 2] + 
  Subscript[a, 1]*Subscript[x, 1] + 
  Subscript[a, 1]*Subscript[x, 1]^2 + 
  Subscript[a, 2]*Subscript[x, 2] + 
  Subscript[a, 2]*Subscript[x, 2]^2\
\>", "Output"]
}, Open  ]],

Cell["\<\


SetSumFormat, defined in the package, allows to specify which format to adopt \
by default\
\>", "Text"],

Cell[BoxData[
    \(SetSumFormat[Automatic] := \($Auto = True\); \n
    SetSumFormat[Inhibited] := \($Auto = False\); \)], "Input",
  CellFrame->True,
  InitializationCell->True,
  Background->GrayLevel[0.833326]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetSumFormat[Automatic]; \nSumma[x^k, {k, 0, \[Infinity]}]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`1\/\(1 - x\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetSumFormat[Inhibited]; \nSumma[x^k, {k, 0, \[Infinity]}]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", \(k = 0\), 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]], \(x\^k\)}],
        HoldForm], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Other Sum formats (*)", "Subsubsection"],

Cell["There are plans to add other sum format type such as", "Text"],

Cell[BoxData[
    \(\(\t\[Sum]\+\(a \[LessEqual] k \[LessEqual] b\)p\_k\n\t
        \(\[Sum]\+\(k \[Element] S\)p\_k\)\)\)], "Text"],

Cell["\<\
Since some of this formats would require the rewriting of most of \
the associated manipulation procedures, only a formatting option is to be \
added. The idea is to allow the conversion of expression from one form into \
the other (so some informartion wuold be stored and hidden inside the Summa \
structure) and use it for typesetting purpose sonly.
But this is is still an unimplemented feature.\
\>", "Text"],

Cell[BoxData[
    \(SetSumFormat[ftype_] := 
      \[IndentingNewLine]Switch[ftype, 
        \[IndentingNewLine]\[IndentingNewLine]Automatic, 
        \[IndentingNewLine]Format[Summa[el_, {k_Symbol, k0_, k1_}]] := 
          \[IndentingNewLine]Block[{$EnableSumEvaluation = True}, 
            \[IndentingNewLine]Sum[el, {k, k0, k1}]\[IndentingNewLine]], 
        \[IndentingNewLine]\[IndentingNewLine]Inhibited, 
        \[IndentingNewLine]Format[Summa[el_, {k_Symbol, k0_, k1_}]] := 
          \[IndentingNewLine]Block[{$EnableSumEvaluation = True}, 
            \[IndentingNewLine]HoldForm[Sum[el, {k, k0, k1}]]
              \[IndentingNewLine]], 
        \[IndentingNewLine]\[IndentingNewLine]Inequality, 
        \[IndentingNewLine]Format[Summa[el_, {k_Symbol, k0_, k1_}]] := 
          \[IndentingNewLine]Block[{$EnableSumEvaluation = True}, 
            \[IndentingNewLine]HoldForm[Sum[el, {k, k0, k1}]]
              \[IndentingNewLine]], 
        \[IndentingNewLine]\[IndentingNewLine]Set, 
        \[IndentingNewLine]Format[Summa[el_, {k_Symbol, k0_, k1_}]] := 
          \[IndentingNewLine]Block[{$EnableSumEvaluation = True}, 
            \[IndentingNewLine]HoldForm[Sum[el, {k, k0, k1}]]
              \[IndentingNewLine]], 
        \[IndentingNewLine]\[IndentingNewLine]Characteristic, 
        \[IndentingNewLine]Format[Summa[el_, {k_Symbol, k0_, k1_}]] := 
          \[IndentingNewLine]Block[{$EnableSumEvaluation = True}, 
            \[IndentingNewLine]HoldForm[Sum[el, {k, k0, k1}]]
              \[IndentingNewLine]]\[IndentingNewLine]]\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Extracting sum terms", "Subsection"],

Cell["GetElement[expr]", "Definition"],

Cell["\<\

The following is  a command that allows to extract coefficients from a Summa \
wrapper. It's a very crude procedure and attention should be paid in order \
not to mix coefficients from different sums; moreover the meaning of the \
coeffienct extraction procedures must be clear in the mind of the user since \
these procedures can yield meaningless equalities. GetElement simply deletes \
the Summa[_, {k,a,b}] structure:\
\>", "Text"],

Cell[BoxData[
    \(getElement = Summa[el_, it_] :> el; \n
    GetElement[s_] := s /. getElement\)], "Input",
  CellFrame->True,
  InitializationCell->True,
  Background->GrayLevel[0.833326]],

Cell["\<\
And it does so regardless of the meaning of the expression passed \
to it. Here is an equation with a sound mathematical meaning:\
\>", "Text"],

Cell[BoxData[
    \(espr = 
      2 - 3  x + 5  x^n + Summa[a[k]\ x^k, {k, 0, \[Infinity]}] == 0\)], 
  "Input"],

Cell["\<\
And here is the (nonsensical but as we will se later, useful) \
result of GetElement.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GetElement[espr]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(a(k)\)\ x\^k + 5\ x\^n - 3\ x + 2 == 0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The user must be aware of what he did and consider this result with due \
care, since this equality does ",
  StyleBox["not",
    FontSlant->"Italic"],
  " follow from the above equation. It is nonetheless useful, as it will be \
shown later, to recover the expression of the general coefficient a[k]."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Extracting coefficients from the powers of x", "Subsection"],

Cell[TextData[StyleBox[
"Use with care: it won't work with expressions that have no summa. It does \
not penetrate equations, either.",
  FontColor->GrayLevel[0.500008]]], "Text",
  FontSlant->"Italic"],

Cell["\<\
GetCoefficient[Summa]
GetCoefficient[expr,x,0]\
\>", "Definition"],

Cell["\<\
GetCoefficient is more an hack than a real procedure: it somehow \
manages to extract the coefficients of specified powers of a given variable x \
from simple polynomials and single sums inside an expression. It has been \
slightly modified since version 1.x of this package and should be used with \
the utmost care in order to avoid meaningless results. \
\>", "Text"],

Cell[TextData[{
  "The following code simply applies GetCoefficient to the element inside the \
single sum passed, either alone, or as a part of a bigger expression. Please \
note that the code is designed to cope",
  StyleBox[" with only one sum at the time",
    FontSlant->"Italic"],
  " (it will not apply properly to nested sum, either). Hence, it's up to the \
user to isolate the sum before applying GetCoefficient."
}], "Text"],

Cell[BoxData[
    \(GetCoefficient[Summa[el_, it_], x_, k___] := 
      GetCoefficient[el, x, k]\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[BoxData[
    \(GetCoefficient[s_\  /; Length[Cases[s, _Summa, \[Infinity]]] == 1\ , 
        x_, k___] := 
      GetCoefficient[\(Cases[s, _Summa, \[Infinity]]\)[\([1]\)], x, k]\)], 
  "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[TextData[
"Now we define the 'real' code for GetCoefficient. On version 4 and higher \
Coefficient is nearly perfect for our purposes, and we can resort to it with \
just a slight make-up. It is mostly a matter of renaming, here, to provide an \
interface that could be used unaltered on previous versions too. We add a \
small rule that set sums with zero elements to zero in order to avoid results \
in the form Sum[0,{k,0,\[Infinity]}]."], "Text"],

Cell[BoxData[
    \(GetCoefficient[el_, x_] := Coefficient[el /. Summa[0, _] \[Rule] 0, x]; 
    \nGetCoefficient[el_, x_, n_] := 
      Coefficient[el /. Summa[0, _] -> 0, x, n]; \)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[TextData[{
  "\n\nBut, rule apart, why do we have to bother about renaming Coefficient \
in the first time? The answer is that on version 3 and below it can produce \
results that need further manipulation. For these versions of ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " when the exponent is set to zero or is symbolic, Coefficient gives \
results we don't actually need for our specific purposes. Moreover, it can \
lead to spurious results when the expression and the the power of x are both \
symbolic. The undesired behaviour is exemplified by the following results"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Coefficient[2 - 3  x + 5  x^n, x, 0]\ \) (*version\ 3*) \)\)], 
  "Input",
  Evaluatable->False],

Cell[BoxData[
    \(TraditionalForm\`5\ x\^n + 2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Coefficient[2 - 3  x + 5  x^n, x, n]\ \) (*version\ 3*) \)\)], 
  "Input",
  Evaluatable->False],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(General::"int"\), \( : \ \), 
        "\<\"Integer expected at position \\!\\(TraditionalForm\\`3\\) in \\!\
\\(TraditionalForm\\`\\(Coefficient[\\(\\(\\(5\\\\ x\\^n\\) - \\(3\\\\ x\\) + \
2\\), x, n\\)]\\)\\).\"\>"}], TraditionalForm]], "Message"],

Cell[BoxData[
    \(TraditionalForm\`Coefficient[5\ x\^n - 3\ x + 2, x, n]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Coefficient[4 + c\ x^\((k - 3)\), x^k, 1]\ \) (*version\ 3*) \)\)], 
  "Input",
  Evaluatable->False],

Cell[BoxData[
    \(TraditionalForm\`c\/x\^3\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "(on version 4 and higher - I have yet to check the results in version 5, \
though - the above commands result in 2, 5, 0, respectively). At any rate, \
even if version 3 results can be explained by a 'superficial' parsing of the \
expressions, they give place to an undesired behaviour that does not fit our \
purposes.  Moreover, even in version 4 the behaviour of Coefficient, though \
symbolically correct, is not fully consistent with what ",
  StyleBox["we specifically need",
    FontSlant->"Italic"],
  "; for example we would like to get 2 as an answer to:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Coefficient[2 - 3  x + 5  x^n, x^n, 0]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`2 - 3\ x\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\n\nWe thus need some extra code to take care of the undesired behaviour \
of Coefficient. \n\t- ",
  StyleBox["Enters the hack -",
    FontSlant->"Italic"],
  "\nWe can for instance check that the result does not contain the specified \
variable (please note that this definition actually replaces the one, with \
the same signature, previously introduced."
}], "Text"],

Cell[BoxData[
    \(\(GetCoefficient[el_, x_, n_] := 
      \[IndentingNewLine]Block[
        \[IndentingNewLine]{res = Coefficient[el /. Summa[0, _] -> 0, x^n]}, 
        \[IndentingNewLine]If[FreeQ[res, x], res, 0]\[IndentingNewLine]]; 
    \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[TextData[{
  "Since this rule applied to n=0 lead to an invalid call to Coefficient (x^0 \
evaluates to 1 and Coefficient won't be passed a symbolic variable) we have \
to add one more rule to take care of this.  Incidentally this line of code \
fixes the behaviour that can give back a function of x when the exponent is \
set to 0 even on later versions of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " :"
}], "Text"],

Cell[BoxData[
    \(\(GetCoefficient[el_, x_, 0] := 
      \(el /. {x^_ -> 0, x -> 0}\) /. Summa[0, _] -> 0; \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["\<\
The main rule works fine as long as x is a symbol. When the user \
specifies a power of x, we must split it in order to separate the symbol from \
the exponent (we could make the signature of these procedure more rigorous by \
specifying a particular pattern matching scheme, but we are assuming that the \
user knows what she's doing). We use a default patern to pack in a single \
lina a call to GetCoefficient[el,x^k], too.\
\>", "Text"],

Cell[BoxData[
    \(\(GetCoefficient[el_, x_^k_, n_:  1] := GetCoefficient[el, x, k*n]; 
    \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[CellGroupData[{

Cell["The actual code in the package", "Subsubsection"],

Cell[TextData[{
  "We now have a code that can consistently work on different versions of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". We can add a conditional statement that checks the version number so \
that the 'hack' will be evaluated only on the versions that really need it."
}], "Text"],

Cell[BoxData[
    \(\( (*common\ code*) 
      \[IndentingNewLine]GetCoefficient[Summa[el_, it_], x_, k___] := 
      \(GetCoefficient[el, x, k]\n
          GetCoefficient[
            s_\  /; Length[Cases[s, _Summa, \[Infinity]]] == 1\ , x_, 
            k___] := 
        GetCoefficient[\(Cases[s, _Summa, \[Infinity]]\)[\([1]\)], x, k]\n
          \[IndentingNewLine]\(GetCoefficient[el_, x_] := 
            Coefficient[el /. Summa[0, _] \[Rule] 0, x]; 
          \)\[IndentingNewLine]\(GetCoefficient[el_, x_^k_, n_:  1] := 
            GetCoefficient[el, x, k*\ n]; 
          \)\[IndentingNewLine]\(GetCoefficient[el_, x_, 0] := 
            \(el /. {x^_ \[Rule] 0, x \[Rule] 0}\) /. Summa[0, _] \[Rule] 0; 
          \)\)\)\)], "Input"],

Cell[BoxData[
    \(If[$VersionNumber \[GreaterEqual] 3, 
      \[IndentingNewLine]\[IndentingNewLine] (*code\ for\ later\ versions*) 
        \[IndentingNewLine]GetCoefficient[el_, x_, n_] := 
        Coefficient[el /. Summa[0, _] \[Rule] 0, x, n], 
      \[IndentingNewLine]\[IndentingNewLine] (*code\ for\ earlier\ versions*) 
        \[IndentingNewLine]GetCoefficient[el_, x_, n_] := 
        \[IndentingNewLine]Block[
          \[IndentingNewLine]{
            res = Coefficient[el /. Summa[0, _] \[Rule] 0, x^n]}, 
          \[IndentingNewLine]If[FreeQ[res, x], res, 0]\[IndentingNewLine]]
          \[IndentingNewLine]]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Testing GetCoefficient", "Subsubsection"],

Cell["We can test it, now.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GetCoefficient[2 - 3  x + 5  x^n, x, 0]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GetCoefficient[2 - 3  x + 5  x^n, x, 1]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-3\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GetCoefficient[2 - 3  x + 5  x^n, x^n, 0]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GetCoefficient[2 - 3  x + 5  x^n, x^n, 1]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`5\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GetCoefficient[2 - 3  x + 5  x^n, x, n]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`5\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GetCoefficient[2 - 3  x + 5  x^n - 7  x^\((2  n)\), x^n, 2]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-7\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GetCoefficient[espr, x^k]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0\)], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Basic Operations on Summa Objects", "Section"],

Cell["\<\
Almost every procedure defined in the package Summa.m is inherently \
rule-based and can be applied to every Summa object contained in the \
expression passed to it. This was done to ease the manipulation of equations, \
avoiding the burned of a mapping on both sides of the equality sign. The \
procedures are designed for onedimensional sums only. Multidimensional sums \
can be treated only when they can be explicitly expressed as nested \
onedimensional sums.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Linear combination and simplification", "Subsection"],

Cell[CellGroupData[{

Cell["BringOut and ExpandSum (SumExpand)", "Subsubsection"],

Cell["BringOut[expr]", "Definition"],

Cell["\<\
The following two rules bring everything that does not explicitly \
depend upon the index out of the sum \
\>", "Text"],

Cell[BoxData[
    \(\(outrule1 = {\n
        Summa[f_ + g_, it : {k_Symbol, __}] \[RuleDelayed] 
          Summa[f, it] + Summa[g, it], \n
        Summa[c_\ f_, it : {k_Symbol, __}] \[RuleDelayed] 
          c\ Summa[f, it] /; FreeQ[c, k]\[IndentingNewLine]}; \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[BoxData[
    \(\(outrule2 = 
      Summa[c_, it : {k_Symbol, __}] :> \ c\ Summa[1, it] /; FreeQ[c, k]; 
    \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[BoxData[
    \(BringOut[s_] := s //. Flatten[{outrule1, outrule2}]\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["NEW! in Summa version 2.2", "Text"],

Cell[BoxData[
    \(\(outrule3[x_] = 
      Summa[el_, it : {k_Symbol, __}] :> \ x\ Summa[el/x, it] /; FreeQ[x, k]; 
    \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[BoxData[
    \(BringOut[s_, x_] := s /. outrule3[x]\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["\<\

Here's an example\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f1 = Summa[\((x - 1)\)^2  x\ x^k\ a\_k, {k, 0, \[Infinity]}]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", \(k = 0\), 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]], 
          \(\((x - 1)\)\^2\ x\^\(k + 1\)\ a\_k\)}],
        HoldForm], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f2 = BringOut[f1]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\((x - 1)\)\^2\), " ", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 0\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(x\^\(k + 1\)\ a\_k\)}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BringOut[Summa[f[x], {k, 0, \[Infinity]}]]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(f(x)\), " ", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 0\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], "1"}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["ExpandSum[expr]", "Definition"],

Cell["\<\
ExpandSum expands what is inside every sum and  makes a separate \
sum for each term. It is usually used in connection with BringIn (see later) \
to perform simplifications and reindexing\
\>", "Text"],

Cell[BoxData[
    \(ExpandSum[s_] := ExpandAll[BringOut[s]]\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f3 = ExpandSum[f2]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", \(k = 0\), 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]], \(x\^\(k + 1\)\ a\_k\)}],
                HoldForm],
              "TraditionalForm"], ")"}], " ", \(x\^2\)}], "-", 
        RowBox[{"2", " ", 
          RowBox[{"(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", \(k = 0\), 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]], \(x\^\(k + 1\)\ a\_k\)}],
                HoldForm],
              "TraditionalForm"], ")"}], " ", "x"}], "+", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 0\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(x\^\(k + 1\)\ a\_k\)}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["BringIn and SimplifySum (SumSimplify)", "Subsubsection"],

Cell["BringIn[espr]", "Definition"],

Cell["\<\
BringIn[expr] brings the eventual factor pre-multiplying a sum \
inside the sum symbol. In doing so it performs an automatic expansion of what \
is inside. \
\>", "Text"],

Cell[BoxData[
    \(\(inrule1 = \ 
      c_\ Summa[el1_, it : {k_Symbol, __}] :> 
        Summa[If[$AutoExpand, c\ el1 // Expand, c\ el1], it] /; FreeQ[c, k]; 
    \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["\<\
To avoid this default expansion, the internal variable $AutoExpand \
has to be set to False. This is a variable that's not accessible to the user \
and will be modified only through the options of the calling procedures.\
\>",
   "Text"],

Cell[BoxData[
    \(\($AutoExpand = True; \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[BoxData[
    \(\(BringIn[s_] := s /. inrule1\n\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["NEW! in version 2.2", "Text"],

Cell[BoxData[
    \(\(inrule3[x_] = 
      Summa[el_, it : {k_Symbol, __}] :> \ 
        1/x\ Summa[\ x\ el, {k, lim}] /; FreeQ[x, k]; \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[BoxData[
    \(BringIn[s_, x_] := s /. inrule2[x]\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["Here's an example", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExpandSum[f1]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", \(k = 0\), 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]], \(x\^\(k + 1\)\ a\_k\)}],
                HoldForm],
              "TraditionalForm"], ")"}], " ", \(x\^2\)}], "-", 
        RowBox[{"2", " ", 
          RowBox[{"(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", \(k = 0\), 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]], \(x\^\(k + 1\)\ a\_k\)}],
                HoldForm],
              "TraditionalForm"], ")"}], " ", "x"}], "+", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 0\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(x\^\(k + 1\)\ a\_k\)}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BringIn[%]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 0\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(x\^\(k + 1\)\ a\_k\)}],
            HoldForm],
          "TraditionalForm"], "+", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 0\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(\(-2\)\ x\^\(k + 2\)\ a\_k\)}],
            HoldForm],
          "TraditionalForm"], "+", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 0\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(x\^\(k + 3\)\ a\_k\)}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["SimplifySum[espr]", "Definition"],

Cell["\<\
SimplifySum[espr] reduce all the sums with the same  indexes (that \
is with the same index name, start and final values) to one single sum. \
\>",
   "Text"],

Cell[BoxData[
    \(\(inrule2 = 
      Summa[el1_, it_] + Summa[el2_, it_] :> \n\t\t
        Summa[If[$AutoSimplify, \n\t\t\t\tel1 + el2 // Simplify, \n\t\t\t\t
            el1 + el2], it]; \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["\<\
The variable $AutoSimplify is not accessibible to the user and will \
be modified by means of Options of the functions calling the rule.\
\>", 
  "Text"],

Cell[BoxData[
    \(\($AutoSimplify = True; \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[BoxData[
    \(\(SimplifySum[s_] := \(s /. inrule1\) //. inrule2\n\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["This is how it works:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(expr = ExpandSum[f1 + x\ f2] == 0\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              FormBox[
                TagBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", \(k = 0\), 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]]], \(x\^\(k + 1\)\ a\_k\)}],
                  HoldForm],
                "TraditionalForm"], ")"}], " ", \(x\^3\)}], "-", 
          RowBox[{
            RowBox[{"(", 
              FormBox[
                TagBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", \(k = 0\), 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]]], \(x\^\(k + 1\)\ a\_k\)}],
                  HoldForm],
                "TraditionalForm"], ")"}], " ", \(x\^2\)}], "-", 
          RowBox[{
            RowBox[{"(", 
              FormBox[
                TagBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", \(k = 0\), 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]]], \(x\^\(k + 1\)\ a\_k\)}],
                  HoldForm],
                "TraditionalForm"], ")"}], " ", "x"}], "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(k = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(x\^\(k + 1\)\ a\_k\)}],
              HoldForm],
            "TraditionalForm"]}], "==", "0"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SimplifySum[expr]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 0\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], 
              \(\((x - 1)\)\^2\ x\^\(k + 1\)\ \((x + 1)\)\ a\_k\)}],
            HoldForm],
          "TraditionalForm"], "==", "0"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["SimplifySum[espr]", "Definition"],

Cell["\<\
Sometimes it may be useful to operate a simplification of each sum \
separately. For this task we can use the procedure\
\>", "Text"],

Cell[BoxData[
    \(\(SimplifyEachSum[s_] := 
      s /. \ Summa[el_, it_] :> Summa[Simplify[el], it]\n\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SimplifyEachSum[BringIn[expr]]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(k = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(x\^\(k + 1\)\ a\_k\)}],
              HoldForm],
            "TraditionalForm"], "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(k = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(\(-x\^\(k + 2\)\)\ a\_k\)}],
              HoldForm],
            "TraditionalForm"], "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(k = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(\(-x\^\(k + 3\)\)\ a\_k\)}],
              HoldForm],
            "TraditionalForm"], "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(k = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(x\^\(k + 4\)\ a\_k\)}],
              HoldForm],
            "TraditionalForm"]}], "==", "0"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reindexing", "Subsection"],

Cell[CellGroupData[{

Cell["BreakSum (SumSplit)", "Subsubsection"],

Cell["BreakSum[espr,n]", "Definition"],

Cell["\<\
BreakSum[espr,n0] splits all the sums contained in espr in order to \
get one sum that  starts from the value n0. The sums with numerical starting \
and ending points are automatically expanded (as is for Sum).\
\>", "Text"],

Cell[BoxData[
    \(\(splitrule[n_] = 
      Summa[el_, {k_, ko_, k1_}] :> \n\t
        Summa[el, {k, ko, n - 1}] + Summa[el, {k, n, k1}]; \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[BoxData[
    \(\(BreakSum[s_, n_Integer] := s /. splitrule[n]\n\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["\<\
Here is a sample sum and its equivaled decomposition with one part \
whose index starts form 0\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((f0 = Summa[a\_k\ x^k, {k, \(-\[Infinity]\), \[Infinity]}])\) 
      \[Equal] \((f01 = BreakSum[f0, 0])\)\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", 
                  InterpretationBox[\(-\[Infinity]\),
                    DirectedInfinity[ -1]]}], 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(x\^k\ a\_k\)}],
            HoldForm],
          "TraditionalForm"], "==", 
        RowBox[{
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(k = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(x\^k\ a\_k\)}],
              HoldForm],
            "TraditionalForm"], "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"k", "=", 
                    InterpretationBox[\(-\[Infinity]\),
                      DirectedInfinity[ -1]]}], \(-1\)], \(x\^k\ a\_k\)}],
              HoldForm],
            "TraditionalForm"]}]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Here we create a sum whose index ranges from 2 to the highest value\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((f1 = Summa[\((x - 1)\)^2  x\ x^k\ a\_k, {k, 0, \[Infinity]}])\) 
      \[Equal] \((f12 = BreakSum[f1, 2])\)\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 0\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], 
              \(\((x - 1)\)\^2\ x\^\(k + 1\)\ a\_k\)}],
            HoldForm],
          "TraditionalForm"], "==", 
        RowBox[{
        \(x\ a\_0\ \((x - 1)\)\^2\), "+", \(x\^2\ a\_1\ \((x - 1)\)\^2\), 
          "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(k = 2\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], 
                \(\((x - 1)\)\^2\ x\^\(k + 1\)\ a\_k\)}],
              HoldForm],
            "TraditionalForm"]}]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
As is the case for the other procedures, BreakSum too can be \
applied to composite expressions, such as equations\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BreakSum[f0 + f1 == 0, 2]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
        \(x\ a\_0\ \((x - 1)\)\^2\), "+", \(x\^2\ a\_1\ \((x - 1)\)\^2\), 
          "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(k = 2\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(x\^k\ a\_k\)}],
              HoldForm],
            "TraditionalForm"], "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"k", "=", 
                    InterpretationBox[\(-\[Infinity]\),
                      DirectedInfinity[ -1]]}], "1"], \(x\^k\ a\_k\)}],
              HoldForm],
            "TraditionalForm"], "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(k = 2\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], 
                \(\((x - 1)\)\^2\ x\^\(k + 1\)\ a\_k\)}],
              HoldForm],
            "TraditionalForm"]}], "==", "0"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(%\  // \ SimplifySum\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
        \(x\ a\_0\ \((x - 1)\)\^2\), "+", \(x\^2\ a\_1\ \((x - 1)\)\^2\), 
          "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"k", "=", 
                    InterpretationBox[\(-\[Infinity]\),
                      DirectedInfinity[ -1]]}], "1"], \(x\^k\ a\_k\)}],
              HoldForm],
            "TraditionalForm"], "+", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(k = 2\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], 
                \(x\^k\ \((x\^3 - 2\ x\^2 + x + 1)\)\ a\_k\)}],
              HoldForm],
            "TraditionalForm"]}], "==", "0"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["ReIndexSum (SumReIndex)", "Subsubsection"],

Cell[TextData["ReIndexSum[ espr, k\[Rule] ( k+offset) ]"], "Definition"],

Cell[TextData[
"ReIndexSum[espr,k\[Rule]new[k]] changes the index as indicated in new[k], \
where new[k] is a 1:1 function of k over the set of possible values permitted \
(a permutation of the indices k). The transformation affects every sum \
contained in espr that has index k. It is not allowed to change the index \
name (a simple replacement can do that) and new[k] must explicitly depend on \
k. Linear functions are most commonly used to perform this task. \nThe new \
version allows for a more flexible manipulation of the indices. When the \
endpoints are finite, we can use solve to allow for more general functions \
new[k]."], "Text"],

Cell[BoxData[
    \(\(ruleIndex[k_, newk_] /; \(! FreeQ[newk, k]\) = 
      Summa[el_, {k, ko_, k1_}] :> \n\t
        Summa[\[IndentingNewLine]el /. k \[Rule] newk, 
          \[IndentingNewLine]{k, k /. First[Solve[newk \[Equal] ko, k]], 
            k /. First[Solve[newk \[Equal] k1, k]]}\[IndentingNewLine]]; 
    \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["\<\
It is possible to check for the existence of the solution \
(Semantica seems to be a neat way to do that, but its beyond the scope of \
this notebook). \
\>", "Text"],

Cell["\<\
Care must be exerted in order to adapt the function to the finite \
set of indices. Also, Solve can cope well with infinities, but it could be \
advisable to give it a little help in order to avoid to specifiy that a \
quantity has to be real and positive. For example, suppose we perform the \
following linear transformation of the index\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Summa[a\_k, {k, 0, \[Infinity]}] /. ruleIndex[k, a\ k + b]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(Power::"indet"\), \( : \ \), 
        "\<\"Indeterminate expression \\!\\(TraditionalForm\\`0\\^0\\) \
encountered.\"\>"}], TraditionalForm]], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(Power::"indet"\), \( : \ \), 
        "\<\"Indeterminate expression \\!\\(TraditionalForm\\`0\\^0\\) \
encountered.\"\>"}], TraditionalForm]], "Message"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", \(k = \(-\(b\/a\)\)\), 
            FractionBox[
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]], "a"]], \(a\_\(b + a\ k\)\)}],
        HoldForm], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
The sign of the coefficient a is important in making the correct \
choice of Infinity. We could nonetheless fix up a solving function that not \
only checks for the invertibility of the index transformation, but \
automatically assumes that every symbolic parameter contained therein be \
positive. Maybe this will be added in a future realease. For the time being \
we rig up ReIndexSum in the usual rule-based fashion.\
\>", "Text"],

Cell[BoxData[
    \(\(ReIndexSum[s_, k_ -> j_] := 
      s /. ruleIndex[k, j]\[IndentingNewLine]\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["\<\
Let's see a couple of examples: this shifts the index of the \
following sum by two positions to the right\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(f1 + x\ f2 // BringIn\), 
    \(ReIndexSum[%, k -> k - 2]\)}], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 0\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], 
              \(\((x - 1)\)\^2\ x\^\(k + 1\)\ a\_k\)}],
            HoldForm],
          "TraditionalForm"], "+", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 0\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], 
              \((a\_k\ x\^\(k + 2\) - 2\ a\_k\ x\^\(k + 3\) + 
                  a\_k\ x\^\(k + 4\))\)}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 2\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], 
              \(\((x - 1)\)\^2\ x\^\(k - 1\)\ a\_\(k - 2\)\)}],
            HoldForm],
          "TraditionalForm"], "+", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 2\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], 
              \((a\_\(k - 2\)\ x\^k - 2\ a\_\(k - 2\)\ x\^\(k + 1\) + 
                  a\_\(k - 2\)\ x\^\(k + 2\))\)}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["AlignIndex (SumIndexAlign)", "Subsubsection"],

Cell["AlignIndex[ espr, {k,k0} ]", "Definition"],

Cell["\<\
We can define a rule that will align the indexes of every summa \
object contained in expr. This is strictly a change of variable, and should \
not be confused with BreakSum, that explicitates part of the sums in order to \
have them start from (or end to) the same value of the index.\
\>", "Text"],

Cell[BoxData[
    \(\(indexShift[{k_, o_}] = 
      Summa[el_, {k, ko_, k1_}] :> \n\t
        Summa[el /. k -> k - o + ko, {k, o, k1 - ko + o}]; \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[BoxData[
    \(\(AlignIndex[s_, {k_, o_}] := s /. indexShift[{k, o}]\n\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["As an example consider", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f = 
      Summa[a\_k, {k, 2, \[Infinity]}] - 
        5  Summa[b\_k, {k, \(-1\), \[Infinity]}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 2\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(a\_k\)}],
            HoldForm],
          "TraditionalForm"], "-", 
        RowBox[{"5", " ", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(k = \(-1\)\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(b\_k\)}],
              HoldForm],
            "TraditionalForm"]}]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlignIndex[f, {k, 0}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 0\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(a\_\(k + 2\)\)}],
            HoldForm],
          "TraditionalForm"], "-", 
        RowBox[{"5", " ", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(k = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(b\_\(k - 1\)\)}],
              HoldForm],
            "TraditionalForm"]}]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
We can overload this procedure in order to handle the sums with \
indices ranging down to minus infinity. A 'fake' option will suite our needs.\
\
\>", "Text"],

Cell[BoxData[
    \(\(indexDownShift[{k_, o_}] = 
      Summa[el_, {k, ko_, k1_}] :> \n\t
        Summa[el /. k -> k - o + k1, {k, ko - k1 + o, o}]; \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[BoxData[
    \(\(AlignIndex[s_, {k_, o_}, Direction -> Down] := 
      s /. indexDownShift[{k, o}]\n\n\t\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["Let's test it", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f = 
      Summa[a\_k, {k, \(-\[Infinity]\), 2}] - 
        5  Summa[b\_k, {k, \(-\[Infinity]\), \(-1\)}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", 
                  InterpretationBox[\(-\[Infinity]\),
                    DirectedInfinity[ -1]]}], "2"], \(a\_k\)}],
            HoldForm],
          "TraditionalForm"], "-", 
        RowBox[{"5", " ", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"k", "=", 
                    InterpretationBox[\(-\[Infinity]\),
                      DirectedInfinity[ -1]]}], \(-1\)], \(b\_k\)}],
              HoldForm],
            "TraditionalForm"]}]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlignIndex[f, {k, 0}, Direction -> Down]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", 
                RowBox[{"k", "=", 
                  InterpretationBox[\(-\[Infinity]\),
                    DirectedInfinity[ -1]]}], "0"], \(a\_\(k + 2\)\)}],
            HoldForm],
          "TraditionalForm"], "-", 
        RowBox[{"5", " ", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", 
                  RowBox[{"k", "=", 
                    InterpretationBox[\(-\[Infinity]\),
                      DirectedInfinity[ -1]]}], "0"], \(b\_\(k - 1\)\)}],
              HoldForm],
            "TraditionalForm"]}]}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["AlignExponent (SumExponentAlign)", "Subsubsection"],

Cell[TextData["AlignExponent[espr, x, k\[Rule]k0]"], "Definition"],

Cell["\<\
AlignExponent allows to shift the indexes of all the series \
contained in expr in such a way that all the exponents of x are the same. \
This line makes it easier to treat non-numerical basis (but it has to be \
applied after due simplification)\
\>", "Text"],

Cell[BoxData[
    \(GetExponent[espr_, x_] := 
      \(Flatten[Cases[{espr}, x^n_\  -> n, \[Infinity]]]\)[\([1]\)]\)], 
  "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["Here's how it differs from the built-in function Exponent", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(espr = \((x - 1)\)^n + 3  x^5; 
    \n{{"\<Expression\>", "\<Exponent\>", "\<GetExponent\>"}, {3  x^5, 
          Exponent[espr, x], GetExponent[espr, x]}, {\((x - 1)\)^n, 
          Exponent[espr, x - 1], GetExponent[espr, x - 1]}} // TableForm\)], 
  "Input"],

Cell[BoxData[
    FormBox[
      TagBox[GridBox[{
            {"\<\"Expression\"\>", "\<\"Exponent\"\>", 
              "\<\"GetExponent\"\>"},
            {\(3\ x\^5\), "5", "5"},
            {\(\((x - 1)\)\^n\), "0", "n"}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        Function[ BoxForm`e$, 
          TableForm[ BoxForm`e$]]], TraditionalForm]], "Output"]
}, Open  ]],

Cell["The rule that does most of the re-aligning work is:", "Text"],

Cell[BoxData[
    \(\(powerShift[x_, k_Symbol -> kin_] = 
      Summa[el_, {k, k0_, k1_}] :> \n\t
        Summa[el /. k -> kin - GetExponent[el, x] + k, {k, 
            k0 - kin + GetExponent[el, x], k1 - kin + GetExponent[el, x]}]; 
    \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["\<\
The procedure to employ has an option, Explode, that can be used to \
disable the default simplification\
\>", "Text"],

Cell[BoxData[
    \(Options[AlignExponent] = {Explode -> True}; \n
    AlignExponent[s_, x_, k_ -> kin_, opts___] := \n\t
      Module[\n\t\t{opt1, res}, \n\t\t
        opt1 = \(Explode /. {opts}\) /. Options[AlignExponent]; \n\t\t
        res = If[opt1, \n\t\t\t\tBringIn[ExpandSum[s]], \n
              \t\t\t\t$Explode = False; BringIn[s]\n\t\t\t\t] /. 
            powerShift[x, k -> kin]; \n\t\t$Explode = True; \n\t\tres\n\t]
        \)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["Some examples follow", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f = Summa[\(a\_k\) x^\((k - 2)\), {k, 0, \[Infinity]}]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", \(k = 0\), 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]], \(x\^\(k - 2\)\ a\_k\)}],
        HoldForm], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlignExponent[f, x, k -> k + 1]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", \(k = \(-3\)\), 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]], \(x\^\(k + 1\)\ a\_\(k + 3\)\)}],
        HoldForm], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f + f1\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 0\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(x\^\(k - 2\)\ a\_k\)}],
            HoldForm],
          "TraditionalForm"], "+", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 0\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], 
              \(\((x - 1)\)\^2\ x\^\(k + 1\)\ a\_k\)}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlignExponent[f + f1, x, k -> k]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 3\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(x\^k\ a\_\(k - 3\)\)}],
            HoldForm],
          "TraditionalForm"], "+", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 2\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(\(-2\)\ x\^k\ a\_\(k - 2\)\)}],
            HoldForm],
          "TraditionalForm"], "+", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 1\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(x\^k\ a\_\(k - 1\)\)}],
            HoldForm],
          "TraditionalForm"], "+", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = \(-2\)\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(x\^k\ a\_\(k + 2\)\)}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f = Summa[\(a\_k\) x^\((k - 1/2)\), {k, 1, \[Infinity]}]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", \(k = 1\), 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]], \(x\^\(k - 1\/2\)\ a\_k\)}],
        HoldForm], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlignExponent[f, x, k -> k - 3/2]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", \(k = 2\), 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]], \(x\^\(k - 3\/2\)\ a\_\(k - 1\)\)}],
        HoldForm], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Here is an example in which it is not devisable to perform an \
automatic simplification :\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(s1 = Summa[\(a\_k\) \((x - xo)\)^\((k - 2)\), {k, 0, \[Infinity]}]\)], 
  "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", \(k = 0\), 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]], \(\((x - xo)\)\^\(k - 2\)\ a\_k\)}],
        HoldForm], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlignExponent[s1, x - xo, k -> k + 1]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", \(k = \(-1\)\), 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]], 
          \(\(\((x - xo)\)\^\(k + 1\)\ a\_\(k + 1\)\)\/\(x\^2 - 2\ xo\ x + 
                xo\^2\)\)}],
        HoldForm], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
The fact is that the expansion performed inside the sum destroys \
the (x-xo)^(k-2) term, hence the matching is not correct. Setting Explode to \
False will avoid this problem\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlignExponent[s1, x - xo, k -> k + 1, Explode -> False]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", \(k = \(-3\)\), 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]], 
          \(\((x - xo)\)\^\(k + 1\)\ a\_\(k + 3\)\)}],
        HoldForm], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Term by Term Differentiation and Integration", "Section"],

Cell[CellGroupData[{

Cell["Basic term by term Differentiation", "Subsection"],

Cell["\<\
The following procedures are intended for using in the 'by hand' \
resolution of ordinary differential equations by means of the power series \
and Frobenius methods. The differentiation of the sums in these instances is \
performed at the beginning of the manipulation, and it is usually done on \
each series separately. Yet the procedures allow for  somewhat a higher \
flexibility.\
\>", "Text"],

Cell[CellGroupData[{

Cell["DSum", "Subsubsection"],

Cell["\<\
DSum[espr,x]
DSum[espr,{x,n}]

Option: Inside (True/False)\
\>", "Definition"],

Cell[TextData[{
  "The basic rules to do this contemplate the basic properties of the \
differentiation operation:  we resort to a dummy head \"d\" to perform our \
simplifications in subsequent steps. Since version 2.1 the restriction that \
the variable with respect to which differentiate be a symbol has been \
removed. This will allow to differentiate with respect to indexed variables \
such as x[j] or ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  ". Since no error control is performed, it is up to the user not to submit \
nonsensical variables to the procedure.\nFirst thing first we implement the \
basic linearity relationship"
}], "Text"],

Cell[BoxData[
    \(Clear[f, f1, f2, c, x, d, diffRule0, diffRule1, diffRule2, diffRule]
      \)], "Input"],

Cell[BoxData[
    \(\(diffRule0[x_] = \n
      \t{\n\td[c_\ f_] :> c\ d[f]\  /; \ FreeQ[c, x], \n\t
        d[f1_ + f2_] :> d[f1] + d[f2]\n\t}; \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell["\<\
After that we can put other more specific rules. The product rule \
is the only one necessary to make the command suitable for the application of \
the power method to ordinary differential equations. Other rules can be \
added, though, most notably the rules for the derivative of the quotient and \
of the power of a function.\
\>", "Text"],

Cell[BoxData[
    \(\(diffRule1[x_] = \n
      \t{\n\td[f1_\ f2_] :> d[f1] f2 + f1\ d[f2], \n\t
        d[f_^c_] :> c\ f^\((c - 1)\)\ d[f]\  /; \ FreeQ[c, x], \n\t
        d[f1_/f2_] :> \((d[f1]\ f2 - f\ 1  d[f2])\)/f2^2, \n\t
        d[f1_[f2_]] :> \ d[f2] D[f1[dummy], dummy] /. dummy -> f2\n\t}; 
    \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(diffRule[x_] = Flatten[{diffRule0[x], diffRule1[x]}]; \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[TextData[{
  "Lastly, we need a rule to differentiate inside the sums (it is assumed \
that the user knows when this is allowed), substituting for d when all of the \
previous properties have been applied. Note that the expressions that do not \
contain Summa object are differentiated by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " in the usual way, thus applying every conceivable rule. This means that \
the rules given in diffRule2 are limiting only in the case of expressions \
containing sums."
}], "Text"],

Cell[BoxData[
    \(\(diffRule2[x_] = \n
      \t{\n\td[Summa[el_, it_]] :> Summa[D[el, x], it], \n\t
        d[f_] :> D[f, x] /; \ FreeQ[f, Summa]\n\t}; \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["\<\
The procedure DSum, collecting all the steps, is given an option so \
that the user can choose whether to  bring inside  or not all  the factors \
premultiplying sums. Note that diffRule is applied recursively, while \
diffRule2 is not.\
\>", "Text"],

Cell[BoxData[{
    \(Clear[DSum]\), 
    \(Options[DSum] = {Inside -> True}; \n
    DSum[s_, x_, opts___] := \n\t
      Module[\n\t\t{opt1}, \n\t\t
        opt1 = \(Inside /. {opts}\) /. Options[DSum]; \n\t\t
        \(d[If[opt1, BringIn[s], s]] //. diffRule[x]\) /. diffRule2[x]\n\t]
        \)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["\<\
This overloads the procedure in order to handle equations \
directly\
\>", "Text"],

Cell[BoxData[
    \(DSum[lhs_ == rhs_, x_, opts___] := 
      DSum[lhs, x, opts] == DSum[rhs, x, opts]\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["And this allows for multiple differentiation:", "Text"],

Cell[BoxData[
    \(DSum[s_, {x_, n_}, opts___] := Nest[DSum[#, x, opts]&, s, n]\)], "Input",\

  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["\<\


Now we can test it, bearing in mind that it was devised for basic \
manipulation only\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[DSum[Summa[\(a\_k\) x^k, {k, 0, \[Infinity]}], {x, n}], \n
        \t{n, 0, 3}] // TableForm\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox[
                TagBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", \(k = 0\), 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]]], \(x\^k\ a\_k\)}],
                  HoldForm],
                "TraditionalForm"]},
            {
              FormBox[
                TagBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", \(k = 0\), 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]]], \(k\ x\^\(k - 1\)\ a\_k\)}],
                  HoldForm],
                "TraditionalForm"]},
            {
              FormBox[
                TagBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", \(k = 0\), 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]]], 
                    \(\((k - 1)\)\ k\ x\^\(k - 2\)\ a\_k\)}],
                  HoldForm],
                "TraditionalForm"]},
            {
              FormBox[
                TagBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", \(k = 0\), 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]]], 
                    \(\((k - 2)\)\ \((k - 1)\)\ k\ x\^\(k - 3\)\ a\_k\)}],
                  HoldForm],
                "TraditionalForm"]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {
          Summa[ 
            Times[ 
              Power[ x, k], 
              Subscript[ a, k]], {k, 0, 
            DirectedInfinity[ 1]}], 
          Summa[ 
            Times[ k, 
              Power[ x, 
                Plus[ -1, k]], 
              Subscript[ a, k]], {k, 0, 
            DirectedInfinity[ 1]}], 
          Summa[ 
            Times[ 
              Plus[ -1, k], k, 
              Power[ x, 
                Plus[ -2, k]], 
              Subscript[ a, k]], {k, 0, 
            DirectedInfinity[ 1]}], 
          Summa[ 
            Times[ 
              Plus[ -2, k], 
              Plus[ -1, k], k, 
              Power[ x, 
                Plus[ -3, k]], 
              Subscript[ a, k]], {k, 0, 
            DirectedInfinity[ 1]}]}]], TraditionalForm]], "Output"]
}, Open  ]],

Cell["Obviously, the first n terms are zero, as can be seen by", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
        BreakSum[\n\t\t
          DSum[Summa[\(a\_k\) x^k, {k, 0, \[Infinity]}], {x, n}], n], \n
        \t{n, 0, 3}] // TableForm\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox[
                TagBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", \(k = 0\), 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]]], \(x\^k\ a\_k\)}],
                  HoldForm],
                "TraditionalForm"]},
            {
              FormBox[
                TagBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", \(k = 1\), 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]]], \(k\ x\^\(k - 1\)\ a\_k\)}],
                  HoldForm],
                "TraditionalForm"]},
            {
              FormBox[
                TagBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", \(k = 2\), 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]]], 
                    \(\((k - 1)\)\ k\ x\^\(k - 2\)\ a\_k\)}],
                  HoldForm],
                "TraditionalForm"]},
            {
              FormBox[
                TagBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", \(k = 3\), 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]]], 
                    \(\((k - 2)\)\ \((k - 1)\)\ k\ x\^\(k - 3\)\ a\_k\)}],
                  HoldForm],
                "TraditionalForm"]}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {
          Summa[ 
            Times[ 
              Power[ x, k], 
              Subscript[ a, k]], {k, 0, 
            DirectedInfinity[ 1]}], 
          Summa[ 
            Times[ k, 
              Power[ x, 
                Plus[ -1, k]], 
              Subscript[ a, k]], {k, 1, 
            DirectedInfinity[ 1]}], 
          Summa[ 
            Times[ 
              Plus[ -1, k], k, 
              Power[ x, 
                Plus[ -2, k]], 
              Subscript[ a, k]], {k, 2, 
            DirectedInfinity[ 1]}], 
          Summa[ 
            Times[ 
              Plus[ -2, k], 
              Plus[ -1, k], k, 
              Power[ x, 
                Plus[ -3, k]], 
              Subscript[ a, k]], {k, 3, 
            DirectedInfinity[ 1]}]}]], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\

The following shows an application of the Inside option: setting Inside to \
False causes the product to be differentiated according to the rule D[f \
g]=D[f] g+f D[g]\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(s = x^2  Summa[\(a\_k\) x^k, {k, 0, \[Infinity]}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(x\^2\), " ", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 0\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(x\^k\ a\_k\)}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSum[\ s, x]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", \(k = 0\), 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]], \(\((k + 2)\)\ x\^\(k + 1\)\ a\_k\)}],
        HoldForm], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSum[\ s, x, Inside -> False]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", \(k = 0\), 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]], \(k\ x\^\(k - 1\)\ a\_k\)}],
                HoldForm],
              "TraditionalForm"], ")"}], " ", \(x\^2\)}], "+", 
        RowBox[{"2", " ", 
          RowBox[{"(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", \(k = 0\), 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]], \(x\^k\ a\_k\)}],
                HoldForm],
              "TraditionalForm"], ")"}], " ", "x"}]}], TraditionalForm]], 
  "Output"]
}, Open  ]],

Cell["\<\
We can recover the previous result by means of a suitable \
simplification\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SimplifySum[BringIn[%]]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", \(k = 0\), 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]], \(\((k + 2)\)\ x\^\(k + 1\)\ a\_k\)}],
        HoldForm], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "DSum can be applied to expression not containing sums... (in this case the \
",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "D operator will take care of the differentiation)"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Clear[f, g, x]; \nDSum[f[x], x]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "(", "x", ")"}], TraditionalForm]], 
  "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSum[f[x] g[x], x]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(g(x)\), " ", 
          RowBox[{
            SuperscriptBox["f", "\[Prime]",
              MultilineFunction->None], "(", "x", ")"}]}], "+", 
        RowBox[{\(f(x)\), " ", 
          RowBox[{
            SuperscriptBox["g", "\[Prime]",
              MultilineFunction->None], "(", "x", ")"}]}]}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["...and to mixed expressions, even in the form of equations", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(expr = 
      Summa[\(a\_k\) x^\((k - 2)\) \((x - Sin[x])\), {k, 5, \[Infinity]}] + 
        2  a\_\(1\ \)/x^3\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\(2\ a\_1\)\/x\^3\), "+", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 5\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], 
              \(x\^\(k - 2\)\ \((x - sin(x))\)\ a\_k\)}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSum[expr, x]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 5\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], 
              \((\((k - 2)\)\ \((x - sin(x))\)\ a\_k\ x\^\(k - 3\) + 
                  \((1 - cos(x))\)\ a\_k\ x\^\(k - 2\))\)}],
            HoldForm],
          "TraditionalForm"], "-", \(\(6\ a\_1\)\/x\^4\)}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(expr1 = f[x] \((g[x] + Summa[h[x, k], {k, 0, \[Infinity]}])\) == 0\)], 
  "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(f(x)\), " ", 
          RowBox[{"(", 
            RowBox[{\(g(x)\), "+", 
              FormBox[
                TagBox[
                  RowBox[{
                    UnderoverscriptBox["\[Sum]", \(k = 0\), 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]]], \(h(x, k)\)}],
                  HoldForm],
                "TraditionalForm"]}], ")"}]}], "==", "0"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSum[expr1, x]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{\(g(x)\), "+", 
                FormBox[
                  TagBox[
                    RowBox[{
                      UnderoverscriptBox["\[Sum]", \(k = 0\), 
                        InterpretationBox["\[Infinity]",
                          DirectedInfinity[ 1]]], \(h(x, k)\)}],
                    HoldForm],
                  "TraditionalForm"]}], ")"}], " ", 
            RowBox[{
              SuperscriptBox["f", "\[Prime]",
                MultilineFunction->None], "(", "x", ")"}]}], "+", 
          RowBox[{\(f(x)\), " ", 
            RowBox[{"(", 
              RowBox[{
                FormBox[
                  TagBox[
                    RowBox[{
                      UnderoverscriptBox["\[Sum]", \(k = 0\), 
                        InterpretationBox["\[Infinity]",
                          DirectedInfinity[ 1]]], 
                      RowBox[{
                        SuperscriptBox["h", 
                          TagBox[\((1, 0)\),
                            Derivative],
                          MultilineFunction->None], "(", \(x, k\), ")"}]}],
                    HoldForm],
                  "TraditionalForm"], "+", 
                RowBox[{
                  SuperscriptBox["g", "\[Prime]",
                    MultilineFunction->None], "(", "x", ")"}]}], ")"}]}]}], 
        "==", "0"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(expr2 = f[x] + g[x] Summa[h[x, k], {k, 0, \[Infinity]}] == 0\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(f(x)\), "+", 
          RowBox[{\(g(x)\), " ", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", \(k = 0\), 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]], \(h(x, k)\)}],
                HoldForm],
              "TraditionalForm"]}]}], "==", "0"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSum[expr2, x]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(k = 0\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{\(h(x, k)\), " ", 
                      RowBox[{
                        SuperscriptBox["g", "\[Prime]",
                          MultilineFunction->None], "(", "x", ")"}]}], "+", 
                    RowBox[{\(g(x)\), " ", 
                      RowBox[{
                        SuperscriptBox["h", 
                          TagBox[\((1, 0)\),
                            Derivative],
                          MultilineFunction->None], "(", \(x, k\), ")"}]}]}], 
                  ")"}]}],
              HoldForm],
            "TraditionalForm"], "+", 
          RowBox[{
            SuperscriptBox["f", "\[Prime]",
              MultilineFunction->None], "(", "x", ")"}]}], "==", "0"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(espr = 
      Summa[\((a\_\(k - 5\) + 2  a\_k - a\_\(k - 3\) - b\_\(k - 4\) + 
                b\_\(k - 3\))\) \((\(-x^\((k - 3)\)\))\), {k, 1, 
            \[Infinity]}] - 2  a\_0/\((x^3)\) + a\_0 - 2  a\_2/x - 
        2  a\_1/x + \(a\_1\) x - 2 \( a\_4\) x + x\ b\_0 - b\_0 - x\ b\_1 - 
        2  a\_3\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(-\(\(2\ a\_0\)\/x\^3\)\), "+", \(a\_0\), "+", \(x\ a\_1\), "-", 
        \(\(2\ a\_1\)\/x\), "-", \(\(2\ a\_2\)\/x\), "-", \(2\ a\_3\), "-", 
        \(2\ x\ a\_4\), "+", \(x\ b\_0\), "-", \(b\_0\), "-", \(x\ b\_1\), 
        "+", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 1\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], 
              \(\(-x\^\(k - 3\)\)\ 
                \((a\_\(k - 5\) - a\_\(k - 3\) + 2\ a\_k - b\_\(k - 4\) + 
                    b\_\(k - 3\))\)\)}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSum[espr, x]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\(6\ a\_0\)\/x\^4\), "+", \(\(2\ a\_1\)\/x\^2\), "+", \(a\_1\), "+", 
        \(\(2\ a\_2\)\/x\^2\), "-", \(2\ a\_4\), "+", \(b\_0\), "-", 
        \(b\_1\), "+", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 1\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], 
              \(\(-\((k - 3)\)\)\ x\^\(k - 4\)\ 
                \((a\_\(k - 5\) - a\_\(k - 3\) + 2\ a\_k - b\_\(k - 4\) + 
                    b\_\(k - 3\))\)\)}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["DEachSum", "Subsubsection"],

Cell["DEachSum[expr]", "Definition"],

Cell["\<\
In certain instances it is better to resort to a differentiation of \
what is inside the sums, by using the procedures DEachSum. It  operates on  \
sums only, by crudely applying the differentiation operator inside \
Summa.\
\>", "Text"],

Cell[BoxData[{
    \(DEachSum[s_, x_] := s /. Summa[el_, it_] :> Summa[D[el, x], it]\), 
    \(DEachSum[s_, {x_, n_}] := 
      s /. Summa[el_, it_] :> Summa[D[el, {x, n}], it]\n\t\t\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Basic term by term Integration", "Subsection"],

Cell["\<\
IntegrateSum[espr,x]
IntegrateSum[espr,{x,a,b}]

Option: Inside (True/False)\
\>", "Definition"],

Cell["\<\
Following the definitions given to implement DSum, we can introduce \
the following rule\
\>", "Text"],

Cell[BoxData[
    \(\(intRule1[x_Symbol | {x_Symbol, _, _}] = \n
      \t{\n\tin[f1_ + f2_] :> in[f1] + in[f2], \n\t
        in[c_*f_] :> c\ in[f]\  /; \ FreeQ[c, x]\ , \n\t
        in[f1_\ f2_] :> in[BringIn[Expand[f1\ f2]]]\ \n\t}; \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[TextData[{
  "A second rule operate the actual integration, by moving the operator \
inside Summa objects and letting ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " integrate the non-Summa parts."
}], "Text"],

Cell[BoxData[
    \(\(intRule2[x_] = \n
      \t{\n\tin[Summa[el_, it_]] :> Summa[Integrate[el, x], it], \n\t
        in[f_] :> Integrate[f, x]\n\t}; \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["\<\


We can see that intRule1 does not perform any integration\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(espr = 
      3  x^2 - Sin[x] + 3  x\ y\ Summa[\(b\_n\) x^n, {n, 2, \[Infinity]}]\), 
    \(in[espr]\  //. intRule1[x]\)}], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(3\ x\^2\), "+", 
        RowBox[{"3", " ", "y", " ", 
          RowBox[{"(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", \(n = 2\), 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]], \(x\^n\ b\_n\)}],
                HoldForm],
              "TraditionalForm"], ")"}], " ", "x"}], "-", \(sin(x)\)}], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      RowBox[{\(3\ \(in(x\^2)\)\), "-", \(in(sin(x))\), "+", 
        RowBox[{"3", " ", "y", " ", 
          RowBox[{"in", "(", 
            FormBox[
              TagBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", \(n = 2\), 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]], \(x\^\(n + 1\)\ b\_n\)}],
                HoldForm],
              "TraditionalForm"], ")"}]}]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["Since that is a job for intRule2.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((in[espr]\  //. intRule1[x])\) /. intRule2[x]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(x\^3\), "+", \(cos(x)\), "+", 
        RowBox[{"3", " ", "y", " ", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(n = 2\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], 
                \(\(x\^\(n + 2\)\ b\_n\)\/\(n + 2\)\)}],
              HoldForm],
            "TraditionalForm"]}]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["This is another expression, integrated", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(in[Summa[\(c\_k\) x^k, {k, 0, \[Infinity]}]] //. intRule1[x]\) /. 
      intRule2[x]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", \(k = 0\), 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]], 
          \(\(x\^\(k + 1\)\ c\_k\)\/\(k + 1\)\)}],
        HoldForm], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\


Both rules can be put into a single procedure, allowing an option for taking \
outside the integral sign everything that does not depend on the variable of \
integration. As before, intRule1 is applied repeatedly while intRule2 is \
applied just once.\
\>", "Text"],

Cell[BoxData[
    \(Options[IntegrateSum] = {Inside -> True}; \n
    IntegrateSum[s_, x_, opts___] := \n\t
      Module[\n\t\t{opt1}, \n\t\t
        opt1 = \(Inside /. {opts}\) /. Options[IntegrateSum]; \n\t\t
        If[opt1, \n\t\t\t\(in[BringIn[s]]\  //. intRule1[x]\) /. intRule2[x], 
          \n\t\t\tBringOut[\(in[s] //. intRule1[x]\) /. intRule2[x]]\n\t\t]\n
        \t]\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["Definite integration is allowed", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f = Summa[\(a\_k\) x^\((2  k)\), {k, 0, \[Infinity]}]; 
    \n{f, \n\tIntegrateSum[f, x], \n\tIntegrateSum[f, {x, 0, 1}], \n\t
        IntegrateSum[f, {x, a, b}]} // ColumnForm\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", \(k = 0\), 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]], \(x\^\(2\ k\)\ a\_k\)}],
                "TraditionalForm"]},
            {
              FormBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", \(k = 0\), 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]], 
                  \(\(x\^\(2\ k + 1\)\ a\_k\)\/\(2\ k + 1\)\)}],
                "TraditionalForm"]},
            {
              FormBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", \(k = 0\), 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]], 
                  \(If[Re(k) > \(-\(1\/2\)\), 1\/\(2\ k + 1\), 
                      \[Integral]\_0\%1\( x\^\(2\ k\)\) \[DifferentialD]x]\ 
                    a\_k\)}],
                "TraditionalForm"]},
            {
              FormBox[
                RowBox[{
                  UnderoverscriptBox["\[Sum]", \(k = 0\), 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]], 
                  \(\((b\^\(2\ k + 1\)\/\(2\ k + 1\) - 
                        a\^\(2\ k + 1\)\/\(2\ k + 1\))\)\ a\_k\)}],
                "TraditionalForm"]}
            },
          GridBaseline->{Baseline, {1, 1}},
          ColumnAlignments->{Left}],
        ColumnForm[ {
          Summa[ 
            Times[ 
              Power[ x, 
                Times[ 2, k]], 
              Subscript[ a, k]], {k, 0, 
            DirectedInfinity[ 1]}], 
          Summa[ 
            Times[ 
              Power[ 
                Plus[ 1, 
                  Times[ 2, k]], -1], 
              Power[ x, 
                Plus[ 1, 
                  Times[ 2, k]]], 
              Subscript[ a, k]], {k, 0, 
            DirectedInfinity[ 1]}], 
          Summa[ 
            Times[ 
              If[ 
                Greater[ 
                  Re[ k], 
                  Rational[ -1, 2]], 
                Power[ 
                  Plus[ 1, 
                    Times[ 2, k]], -1], 
                Integrate[ 
                  Power[ x, 
                    Times[ 2, k]], {x, 0, 1}]], 
              Subscript[ a, k]], {k, 0, 
            DirectedInfinity[ 1]}], 
          Summa[ 
            Times[ 
              Plus[ 
                Times[ -1, 
                  Power[ a, 
                    Plus[ 1, 
                      Times[ 2, k]]], 
                  Power[ 
                    Plus[ 1, 
                      Times[ 2, k]], -1]], 
                Times[ 
                  Power[ b, 
                    Plus[ 1, 
                      Times[ 2, k]]], 
                  Power[ 
                    Plus[ 1, 
                      Times[ 2, k]], -1]]], 
              Subscript[ a, k]], {k, 0, 
            DirectedInfinity[ 1]}]}],
        Editable->False], TraditionalForm]], "Output"]
}, Open  ]],

Cell["And, in version 3, we can get conditional integrals", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntegrateSum[espr, {x, 0, 1}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(n = 2\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], 
              \(3\ y\ If[Re(n) > \(-2\), 1\/\(n + 2\), 
                  \[Integral]\_0\%1\( x\^\(n + 1\)\) \[DifferentialD]x]\ 
                b\_n\)}],
            HoldForm],
          "TraditionalForm"], "+", \(cos(1)\)}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. Re[n] > \(-2\) -> True\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(n = 2\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(\(3\ y\ b\_n\)\/\(n + 2\)\)}],
            HoldForm],
          "TraditionalForm"], "+", \(cos(1)\)}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Prior to integrating, factors premultiplying the sum are \
automatically brought inside\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\ s = x\ y\ z^2\ Summa[\(a\_k\) z^k, {k, 0, Infinity}]\)\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"x", " ", "y", " ", \(z\^2\), " ", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 0\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(z\^k\ a\_k\)}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IntegrateSum[s,z]", "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", \(k = 0\), 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]], 
          \(\(x\ y\ z\^\(k + 3\)\ a\_k\)\/\(k + 3\)\)}],
        HoldForm], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[
"Setting the Option Inside\[Rule]False will prevent such a behaviour"], "Text"],

Cell[CellGroupData[{

Cell["IntegrateSum[s,z,Inside->False]", "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"x", " ", "y", " ", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 0\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], 
              \(\(z\^\(k + 3\)\ a\_k\)\/\(k + 3\)\)}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
To force threading over equations we need only add this line of \
code:\
\>", "Text"],

Cell[BoxData[
    \(\(IntegrateSum[lhs_ == rhs_, x_, opts___] := \n\ \ 
      IntegrateSum[lhs, x, opts] == IntegrateSum[rhs, x, opts]\t\n\)\)], 
  "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Clear[f]\), 
    \(IntegrateSum[
      f[x] Exp[I\ m\ x] == 
        Summa[\(c\_n\) Exp[\(-I\)\ n\ x], {n, 0, \[Infinity]}]\ Exp[I\ m\ x], 
      x]\)}], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\[Integral]\(\[ExponentialE]\^\(\[ImaginaryI]\ m\ x\)\ \(f(x)\)\) 
            \[DifferentialD]x\), "==", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(n = 0\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], 
              \(-\(\(\[ImaginaryI]\ 
                      \[ExponentialE]\^\(\[ImaginaryI]\ \((m - n)\)\ x\)\ 
                      c\_n\)\/\(m - n\)\)\)}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\


Other examples follow\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Clear[f]\), 
    \(\ s = f[x]\ Summa[\(a\_k\) x^k, {k, 0, Infinity}]\)}], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(f(x)\), " ", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 0\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(x\^k\ a\_k\)}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IntegrateSum[s,x]", "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", \(k = 0\), 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]], 
          \(\((\[Integral]\(x\^k\ \(f(x)\)\) \[DifferentialD]x)\)\ a\_k\)}],
        HoldForm], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(s = f[x] Summa[\(a\_k\) g[x], {k, 0, \[Infinity]}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(f(x)\), " ", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 0\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(\(g(x)\)\ a\_k\)}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntegrateSum[s, x]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", \(k = 0\), 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]], 
          \(\((\[Integral]\(\(f(x)\)\ \(g(x)\)\) \[DifferentialD]x)\)\ 
            a\_k\)}],
        HoldForm], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BringOut[%]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
      \((\[Integral]\(\(f(x)\)\ \(g(x)\)\) \[DifferentialD]x)\), " ", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 0\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(a\_k\)}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntegrateSum[s, x, Inside -> False]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
      \((\[Integral]\(\(f(x)\)\ \(g(x)\)\) \[DifferentialD]x)\), " ", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 0\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(a\_k\)}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Selectively Applying and Mapping Functions (*)", "Section"],

Cell["\<\
These are untested and undocumented procedures that will be added \
to a later version of the package.\
\>", "Text"],

Cell[CellGroupData[{

Cell["SumPosition", "Subsubsection"],

Cell["SumPosition", "Definition"],

Cell["\<\
We might also want to map a function inside specific sums in a \
given expression. Suppose we want to shift the index of the second sum only \
in\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(expr = 
      Summa[\(a\_k\) x^k, {k, 1, \[Infinity]}] + 3  Cos[x] - 2 == 
        Sqrt[3  x^2] Summa[Cos[k\ x], {k, 1, \[Infinity]}] - 
          2  Summa[\(b\_k\) x^\((k - 2)\), {k, 2, \[Infinity]}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(3\ \(cos(x)\)\), "+", 
          RowBox[{"Summa", "(", 
            RowBox[{\(x\^k\ a\_k\), ",", 
              RowBox[{"{", 
                RowBox[{"k", ",", "1", ",", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]}], "}"}]}], ")"}], "-", "2"}], 
        "==", 
        RowBox[{
          RowBox[{\(\@3\), " ", \(\@x\^2\), " ", 
            RowBox[{"Summa", "(", 
              RowBox[{\(cos(k\ x)\), ",", 
                RowBox[{"{", 
                  RowBox[{"k", ",", "1", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
            RowBox[{"Summa", "(", 
              RowBox[{\(x\^\(k - 2\)\ b\_k\), ",", 
                RowBox[{"{", 
                  RowBox[{"k", ",", "2", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}]}], ")"}]}]}]}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
withoout having to change the index in the other sums appearing in \
expr. We need a procedure that can do what SumMap does but only at specific \
positions.\
\>", "Text"],

Cell[TextData[{
  "We have to redefine the meaning of position in expr to mean something \
simpler than what it really means to ",
  StyleBox["Mathematica.",
    FontSlant->"Italic"],
  " Position k means 'the k-th Sum appearing in expr\". In this particular \
case, the Sum we want to act upon is that in 'summa position' 1. Note that we \
have to refer to the output given by Mathematica since the position in the \
fullform of the expression passed to it can be different from that input by \
the user. This is a side effect of the canonical reordering of functions, \
such as Plus, with attributes like Orderless. As we can see, the position of \
the Summa we want to zero in is"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Position[expr, Summa[Cos[k\ x], {k, 1, \[Infinity]}]]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"2", "1", "3"}
            },
          ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
So, how can we identify its 'summa position' as 1? One way is to \
find the positions of every occurence of Summa in expr\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Position[expr, _Summa]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{{1, 3}, {2, 1, 3}, {2, 2, 2}}\)], "Output"]
}, Open  ]],

Cell["\<\
Then we use the position of the element Position[expr,_Summa] in \
this table as the position for our sum. We need to look up what is the actual \
position associated with the ordinal number 1 in a table like this\
\>", 
  "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Range[Length[%]], %} // Transpose\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", \({1, 3}\)},
            {"2", \({2, 1, 3}\)},
            {"3", \({2, 2, 2}\)}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["hence the position identifying the k-th Sum is ", "Text"],

Cell[BoxData[
    \(SumPosition[expr_, k_] := Part[Position[expr, Summa[_, _]], k]\)], 
  "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["\<\
We can identify the position of the first sum only or of the first \
and third sum appearing in expr. Please note that the actual position is \
referred to the fullform of the expression, so it may necessary to have a \
look at FullForm[expr] to identify the exact place where we want to map our \
function.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SumPosition[expr, 1]\), 
    \(SumPosition[expr, {1, 3}]\)}], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{1, 3}\)], "Output"],

Cell[BoxData[
    \(TraditionalForm\`{{1, 3}, {2, 2, 2}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["SumMap", "Subsubsection"],

Cell["SumMap", "Definition"],

Cell["\<\
Sometimes it may be useful to apply a function to the element of a \
sum without having to worry about the Sum(ma) wrapper., The procedures SumMap \
and SumApply implement a simple mapping scheme to do just that. The \
difference with respect to Map is that without a level specification (or with \
a specification of 0) SumMap will wrap the function around the element of \
every Summa object contained in the expression passed to it. \
\>", "Text"],

Cell[BoxData[{
    \(SumMap[f_, expr_] := 
      expr /. Summa[el_, it_] \[RuleDelayed] Summa[f@el, it]\), 
    \(SumMap[f_, expr_, 0] := SumMap[f, expr]\), 
    \(SumMap[f_, expr_, n_] := 
      expr /. Summa[el_, it_] \[RuleDelayed] Summa[Map[f, el, n], it]\)}], 
  "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell["\<\
It may be useful to perform different kind of transfrormations on \
the elements of the sum. For example, we can map a TrigToExp transformation \
inside every Sum\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(expr = 
      Summa[\(a\_k\) x^k, {k, 1, \[Infinity]}] + 3  Cos[x] - 
        Sqrt[3  x^2] Summa[Cos[k\ x], {k, 1, \[Infinity]}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(3\ \(cos(x)\)\), "-", 
        RowBox[{\(\@3\), " ", \(\@x\^2\), " ", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(k = 1\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], \(cos(k\ x)\)}],
              HoldForm],
            "TraditionalForm"]}], "+", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 1\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(x\^k\ a\_k\)}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SumMap[TrigToExp, expr]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(3\ \(cos(x)\)\), "-", 
        RowBox[{\(\@3\), " ", \(\@x\^2\), " ", 
          FormBox[
            TagBox[
              RowBox[{
                UnderoverscriptBox["\[Sum]", \(k = 1\), 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]], 
                \((1\/2\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ k\ x\) + 
                    1\/2\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ x\))\)}],
              HoldForm],
            "TraditionalForm"]}], "+", 
        FormBox[
          TagBox[
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 1\), 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]], \(x\^k\ a\_k\)}],
            HoldForm],
          "TraditionalForm"]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Collect, Apart, and other simplifications functions can be wrapped \
on the elements, mapped and applied inside every sum.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["SumMapAt", "Subsubsection"],

Cell["\<\
MapAt[f,expr,SumPosition[expr,n]]
SumMapAt\
\>", "Definition"],

Cell["\<\
We might also want to map a function inside specific sums in a \
given expression. Suppose we want to shift the index of the second sum only \
in\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(expr = 
      Summa[\(a\_k\) x^k, {k, 1, \[Infinity]}] + 3  Cos[x] - 2 == 
        Sqrt[3  x^2] Summa[Cos[k\ x], {k, 1, \[Infinity]}] - 
          2  Summa[\(b\_k\) x^\((k - 2)\), {k, 2, \[Infinity]}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(3\ \(cos(x)\)\), "+", 
          RowBox[{"Summa", "(", 
            RowBox[{\(x\^k\ a\_k\), ",", 
              RowBox[{"{", 
                RowBox[{"k", ",", "1", ",", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]}], "}"}]}], ")"}], "-", "2"}], 
        "==", 
        RowBox[{
          RowBox[{\(\@3\), " ", \(\@x\^2\), " ", 
            RowBox[{"Summa", "(", 
              RowBox[{\(cos(k\ x)\), ",", 
                RowBox[{"{", 
                  RowBox[{"k", ",", "1", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
            RowBox[{"Summa", "(", 
              RowBox[{\(x\^\(k - 2\)\ b\_k\), ",", 
                RowBox[{"{", 
                  RowBox[{"k", ",", "2", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}]}], ")"}]}]}]}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "withoout having to change the index in the other sums appearing in expr. \
We need a procedure that can do what SumMap does but only at specific \
positions. This is a task that in ordinary ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " world is accomplished by the function MapAt"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?MapAt\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`"MapAt[f, expr, n] applies f to the element at position n in expr. If n \
is negative, the position is counted from the end. MapAt[f, expr, {i, j, ... \
}] applies f to the part of expr at position {i, j, ... }. MapAt[f, expr, \
{{i1, j1, ... }, {i2, j2, ... }, ... }] applies f to parts of expr at several \
positions."\)], "Print"]
}, Open  ]],

Cell["\<\
All we have to do now is to map our functions at the specific \
positions given, remembering that we need to map them inside the s\
\>", 
  "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MapAt[f, expr, SumPosition[expr, {1, 3}]]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(3\ \(cos(x)\)\), "+", 
          RowBox[{"f", "(", 
            RowBox[{"Summa", "(", 
              RowBox[{\(x\^k\ a\_k\), ",", 
                RowBox[{"{", 
                  RowBox[{"k", ",", "1", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}]}], ")"}], ")"}], "-", 
          "2"}], "==", 
        RowBox[{
          RowBox[{\(\@3\), " ", \(\@x\^2\), " ", 
            RowBox[{"Summa", "(", 
              RowBox[{\(cos(k\ x)\), ",", 
                RowBox[{"{", 
                  RowBox[{"k", ",", "1", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
            RowBox[{"f", "(", 
              RowBox[{"Summa", "(", 
                RowBox[{\(x\^\(k - 2\)\ b\_k\), ",", 
                  RowBox[{"{", 
                    RowBox[{"k", ",", "2", ",", 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]]}], "}"}]}], ")"}], ")"}]}]}]}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(SumMapAt[f_, expr_, pos_] := MapAt[f, expr, SumPosition[expr, pos]]\), 
    \(SumMapAt[f_, expr_, pos_, lev_] := 
      MapAt[Map[f, expr, lev], expr, SumPosition[expr, pos]]\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SumMapAt[f, expr, 2]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(3\ \(cos(x)\)\), "+", 
          RowBox[{"Summa", "(", 
            RowBox[{\(x\^k\ a\_k\), ",", 
              RowBox[{"{", 
                RowBox[{"k", ",", "1", ",", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]}], "}"}]}], ")"}], "-", "2"}], 
        "==", 
        RowBox[{
          RowBox[{\(\@3\), " ", \(\@x\^2\), " ", 
            RowBox[{"f", "(", 
              RowBox[{"Summa", "(", 
                RowBox[{\(cos(k\ x)\), ",", 
                  RowBox[{"{", 
                    RowBox[{"k", ",", "1", ",", 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]]}], "}"}]}], ")"}], ")"}]}], 
          "-", 
          RowBox[{"2", " ", 
            RowBox[{"Summa", "(", 
              RowBox[{\(x\^\(k - 2\)\ b\_k\), ",", 
                RowBox[{"{", 
                  RowBox[{"k", ",", "2", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}]}], ")"}]}]}]}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(x + s - 2\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["SumApply e SumApplyAt", "Subsubsection"],

Cell["SumApply", "Definition"],

Cell[BoxData[
    \(SumApply[f_, expr_, n_:  1] := 
      expr /. Summa[el_, it_] \[RuleDelayed] Summa[Apply[f, el, n], it]\)], 
  "Input",
  CellFrame->True,
  Background->GrayLevel[0.833326]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Further Enhancements (*)", "Section"],

Cell[CellGroupData[{

Cell["Adding new names and options to the procedures", "Subsection"],

Cell["\<\
Version 2.3 adds a new naming for Summa.m's procedures. Most of \
them now start with the string Sum. The older names are retained because the \
author is unbelievalby lazy and wanted to make sure that older notebooks \
would work without having to change any name. The following shows a \
correspondence between new and old names. (The actual package has the \
equalities reversed since the naming was changed in the body of the \
package)\
\>", "Text"],

Cell[BoxData[
    \(GetExponent; \nSumToTerm = GetElement; \n
    SumCoefficient = GetCoefficient; 
    \[IndentingNewLine]SumExpand = ExpandSum; \nSumExpandAll = ExpandAllSum; 
    \nSumSimplify = SimplifySum; \nSumFullSimplify = FullSimplifySum; \n
    SumSimplifyEach = SimplifyEachSum; \n
    SumFullSimplifyEach = FullSimplifyEachSum; \[IndentingNewLine]BringIn; \n
    BringOut; \nSumSplit = BreakSum; 
    \[IndentingNewLine]SumReindex = ReindexSum; \nSumIndexAlign = AlignIndex; 
    \nSumExponentAlign = AlignExponent; \[IndentingNewLine]SumD = DSum; \n
    SumDEach = DEachSum; 
    \  (*\ to\ be\ embedded\ in\ SumD\ with\ option\ SeparateSums \[Rule] 
        True*) \nSumIntegrate = IntegrateSum; \)], "Input"],

Cell["\<\


Moreover, in order to give to the manipulation procedures the same options of \
the built-in procedures they are extending to sum manipulation, part of the \
code of the package had to be modified. Since most procedurs in Summa.m are \
rule based, it has been necessary to modify all of the rules that called the \
procedure with options. Here it is shown how to fix just two procedure: \
BringIn and SumSimplify.\
\>", "Text"],

Cell[BoxData[{
    \(inrule1[opts___] = 
      c_\ Summa[el1_, it : {k_, _, _}] \[RuleDelayed] 
        Summa[If[$Explode, Expand[c\ el1, FilterOptions[Expand, opts]], 
              c\ el1], it] /; FreeQ[c, k]; \n
    inrule2[opts___] = 
      Summa[el1_, it_] + Summa[el2_, it_] \[RuleDelayed] 
        Summa[If[$Semplifica, 
            Simplify[el1 + el2, FilterOptions[Simplify, opts]], el1 + el2], 
          it]; \ninrule3[x_] = 
      Summa[el_, {k_, lim__}] \[RuleDelayed] 
        \((1/x)\)*Summa[x*el, {k, lim}] /; FreeQ[x, k]; \n\n
    BringIn[s_, opts___] := s /. inrule1[opts]\), 
    \(BringIn[s_, x_] := s /. inrule3[x]\n\), 
    \(SumSimplify[s_, opts___] := 
      \(\(s /. inrule1[opts]\) //. inrule2[opts]\) /. 
        Summa[0, _] \[Rule] 0\)}], "Input"],

Cell["\<\
As we can see, not every rule need to be given options. Only those \
calling procedures that needs options.BringIn will accept the same options of \
Expand. In the particular case of inrule2 called by SumSimplify there are two \
built-in procedures carrying options: one is Simplify, and that was to be \
expected; the other one is Expand. By giving options to Expand too, and by \
selecting only valid options for each procedure through the use of \
FilterOptions, we can specify both kind of options in our call to \
SumSimplify.\
\>", "Text"],

Cell[TextData[{
  "Version 2.3 of the package does ",
  StyleBox["not",
    FontSlant->"Italic"],
  " allow the user to specify default values for the options associated to \
any particular Summa.m procedure. It is not difficult to code such an \
extension though. But since version 4 will need to associate such options to \
the built-in procedures themselves, the options are left 'read-only'."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Options[BringIn] = Options[Expand]\), 
    \(Options[SumSimplify] = Union[Options[Simplify], Options[Expand]]\)}], 
  "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Modulus \[Rule] 0, Trig \[Rule] False}\)], "Output"],

Cell[BoxData[
    \(TraditionalForm
    \`{ComplexityFunction \[Rule] Automatic, Modulus \[Rule] 0, 
      TimeConstraint \[Rule] 300, Trig \[Rule] False, Trig \[Rule] True}\)], 
  "Output"]
}, Open  ]],

Cell["\<\
Other procedures, such as SumIntegrate, have options on their own. \
In this case they must be added to those of the built-in procedures they are \
internally using. FilterOptions is needed in order to avoid message \
errors\
\>", "Text"],

Cell[BoxData[
    \(intRule1[x_Symbol | {x_Symbol, _, _}] = {
        in[f1_ + f2_] \[RuleDelayed] in[f1] + in[f2], 
        in[c_\ f_] \[RuleDelayed] c\ in[f] /; FreeQ[c, x], 
        in[f1_\ f2_] \[RuleDelayed] in[BringIn[Expand[f1\ f2]]]}; \n
    intRule2[x_, opts___] = {
        in[Summa[el_, it_]] \[RuleDelayed] Summa[Integrate[el, x, opts], it], 
        in[f_] \[RuleDelayed] Integrate[f, x, opts]\  (*
          \  /; FreeQ[f, Summa]*) }; \[IndentingNewLine]\n
    SumIntegrate[s_, x_, opts___] := 
      Module[\[IndentingNewLine]{opt1, opt2}, 
        \[IndentingNewLine]opt1 = 
          \(Inside /. {opts}\) /. Options[SumIntegrate]; 
        \[IndentingNewLine]opt2 = FilterOptions[Integrate, opts]; 
        \[IndentingNewLine]If[opt1, 
          \[IndentingNewLine]\(in[BringIn[s]] //. intRule1[x]\) /. 
            intRule2[x, opt2], 
          \[IndentingNewLine]BringOut[
            \(in[s] //. intRule1[x]\) /. intRule2[x, opt2]]
            \[IndentingNewLine]]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(\(Options[SumIntegrate] = 
      Union[{Inside \[Rule] True}, Options[Integrate]]; \)\)], "Input"],

Cell["\<\

There's a little note to be made, regarding adding options: the automatic \
reordering of definitions performed by Mathematica is prevented by the \
specification of the pattern for options. If we simpy add opts___, function \
calls that are more specific are automatically placed before the more general \
ones. See for example: \
\>", "Text"],

Cell[BoxData[{
    \(Clear[f]\), 
    \(f[expr_, x_, opts___] := FOO[expr, x]\), 
    \(f[lhs_ \[Equal] rhs_, x_, opts___] := 
      Equal[foo[lhs, x], bar[rhs, x]]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?f\)\)], "Input"],

Cell["Global`f", "Print",
  CellTags->"Info3306637076-9483759"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {
                  \(f[lhs_ == rhs_, x_, opts___] := 
                    foo[lhs, x] == bar[rhs, x]\)},
                {" "},
                {\(f[expr_, x_, opts___] := FOO[expr, x]\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "f"],
      Editable->False]], "Print",
  CellTags->"Info3306637076-9483759"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[Sin[t] == Cos[y], x]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`foo(sin(t), x) == bar(cos(y), x)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "But if we specify that the options have to be Rules, then ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " won't sort the definitions anymore, leaving them in the order the user \
entered them:"
}], "Text"],

Cell[BoxData[{
    \(Clear[f]\), 
    \(f[expr_, x_, opts___Rule] := FOO[expr, x]\), 
    \(f[lhs_ \[Equal] rhs_, x_, opts___Rule] := 
      Equal[foo[lhs, x], bar[rhs, x]]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?f\)\)], "Input"],

Cell["Global`f", "Print",
  CellTags->"Info3306637080-7313910"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(f[expr_, x_, opts___Rule] := FOO[expr, x]\)},
                {" "},
                {
                  \(f[lhs_ == rhs_, x_, opts___Rule] := 
                    foo[lhs, x] == bar[rhs, x]\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "f"],
      Editable->False]], "Print",
  CellTags->"Info3306637080-7313910"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[Sin[t] == Cos[y], x]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`FOO(sin(t) == cos(y), x)\)], "Output"]
}, Open  ]],

Cell["\<\
Of course there is any easy way out: specifying the right order in \
the package\
\>", "Text"],

Cell[BoxData[{
    \(Clear[f]\), 
    \(f[lhs_ \[Equal] rhs_, x_, opts___Rule] := 
      Equal[foo[lhs, x], bar[rhs, x]]\), 
    \(f[expr_, x_, opts___Rule] := foo[expr, x]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?f\)\)], "Input"],

Cell["Global`f", "Print",
  CellTags->"Info3306637088-1035757"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {
                  \(f[lhs_ == rhs_, x_, opts___Rule] := 
                    foo[lhs, x] == bar[rhs, x]\)},
                {" "},
                {\(f[expr_, x_, opts___Rule] := foo[expr, x]\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "f"],
      Editable->False]], "Print",
  CellTags->"Info3306637088-1035757"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[Sin[t] == Cos[y], x]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`foo(sin(t), x) == bar(cos(y), x)\)], "Output"]
}, Open  ]],

Cell["\<\
Since in the actual package the type Rule is specificed for the \
added options, this 'manual' reordering was necessary for the differentiation \
and integration procedures.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Enhancing built-in procedures (*)", "Subsection"],

Cell["To be added in a later, major, version.", "Text"]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1152}, {0, 900}},
WindowToolbars->{},
WindowSize->{774, 551},
WindowMargins->{{22, Automatic}, {Automatic, 15}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "Classroom.nb"]